Class: YNAB::AccountsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ynab/api/accounts_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AccountsApi

Returns a new instance of AccountsApi.



15
16
17
# File 'lib/ynab/api/accounts_api.rb', line 15

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



13
14
15
# File 'lib/ynab/api/accounts_api.rb', line 13

def api_client
  @api_client
end

Instance Method Details

#create_account(plan_id, data, opts = {}) ⇒ AccountResponse

Create an account Creates a new account

Parameters:

  • plan_id (String)

    The id of the plan ("last-used" can be used to specify the last used plan and "default" can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan)

  • data (PostAccountWrapper)

    The account to create.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



24
25
26
27
# File 'lib/ynab/api/accounts_api.rb', line 24

def (plan_id, data, opts = {})
  data, _status_code, _headers = (plan_id, data, opts)
  data
end

#create_account_with_http_info(plan_id, data, opts = {}) ⇒ Array<(AccountResponse, Integer, Hash)>

Create an account Creates a new account

Parameters:

  • plan_id (String)

    The id of the plan (&quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan)

  • data (PostAccountWrapper)

    The account to create.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AccountResponse, Integer, Hash)>)

    AccountResponse data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/ynab/api/accounts_api.rb', line 35

def (plan_id, data, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountsApi.create_account ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling AccountsApi.create_account"
  end
  # verify the required parameter 'data' is set
  if @api_client.config.client_side_validation && data.nil?
    fail ArgumentError, "Missing the required parameter 'data' when calling AccountsApi.create_account"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/accounts'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(data)

  # return_type
  return_type = opts[:debug_return_type] || 'AccountResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"AccountsApi.create_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountsApi#create_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_account_by_id(plan_id, account_id, opts = {}) ⇒ AccountResponse

Get an account Returns a single account

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • account_id (String)

    The id of the account

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



98
99
100
101
# File 'lib/ynab/api/accounts_api.rb', line 98

def (plan_id, , opts = {})
  data, _status_code, _headers = (plan_id, , opts)
  data
end

#get_account_by_id_with_http_info(plan_id, account_id, opts = {}) ⇒ Array<(AccountResponse, Integer, Hash)>

Get an account Returns a single account

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • account_id (String)

    The id of the account

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AccountResponse, Integer, Hash)>)

    AccountResponse data, response status code and response headers



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/ynab/api/accounts_api.rb', line 109

def (plan_id, , opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountsApi.get_account_by_id ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling AccountsApi.get_account_by_id"
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_account_by_id"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/accounts/{account_id}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'account_id' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AccountResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"AccountsApi.get_account_by_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountsApi#get_account_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_accounts(plan_id, opts = {}) ⇒ AccountsResponse

Get all accounts Returns all accounts

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :last_knowledge_of_server (Integer)

    The starting server knowledge. If provided, only entities that have changed since &#x60;last_knowledge_of_server&#x60; will be included.

Returns:



167
168
169
170
# File 'lib/ynab/api/accounts_api.rb', line 167

def get_accounts(plan_id, opts = {})
  data, _status_code, _headers = get_accounts_with_http_info(plan_id, opts)
  data
end

#get_accounts_with_http_info(plan_id, opts = {}) ⇒ Array<(AccountsResponse, Integer, Hash)>

Get all accounts Returns all accounts

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :last_knowledge_of_server (Integer)

    The starting server knowledge. If provided, only entities that have changed since &#x60;last_knowledge_of_server&#x60; will be included.

Returns:

  • (Array<(AccountsResponse, Integer, Hash)>)

    AccountsResponse data, response status code and response headers



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/ynab/api/accounts_api.rb', line 178

def get_accounts_with_http_info(plan_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountsApi.get_accounts ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling AccountsApi.get_accounts"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/accounts'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'last_knowledge_of_server'] = opts[:'last_knowledge_of_server'] if !opts[:'last_knowledge_of_server'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AccountsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"AccountsApi.get_accounts",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountsApi#get_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end