Class: YNAB::BulkResponseDataBulk

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/bulk_response_data_bulk.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BulkResponseDataBulk

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 50

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::BulkResponseDataBulk` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::BulkResponseDataBulk`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'transaction_ids')
    if (value = attributes[:'transaction_ids']).is_a?(Array)
      self.transaction_ids = value
    end
  end

  if attributes.key?(:'duplicate_import_ids')
    if (value = attributes[:'duplicate_import_ids']).is_a?(Array)
      self.duplicate_import_ids = value
    end
  end
end

Instance Attribute Details

#duplicate_import_idsObject

If any Transactions were not created because they had an import_id matching a transaction already on the same account, the specified import_id(s) will be included in this list.



19
20
21
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 19

def duplicate_import_ids
  @duplicate_import_ids
end

#transaction_idsObject

The list of Transaction ids that were created.



16
17
18
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 16

def transaction_ids
  @transaction_ids
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



30
31
32
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 30

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



22
23
24
25
26
27
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 22

def self.attribute_map
  {
    :'transaction_ids' => :'transaction_ids',
    :'duplicate_import_ids' => :'duplicate_import_ids'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 115

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



43
44
45
46
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 43

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



35
36
37
38
39
40
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 35

def self.openapi_types
  {
    :'transaction_ids' => :'Array<String>',
    :'duplicate_import_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



93
94
95
96
97
98
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 93

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      transaction_ids == o.transaction_ids &&
      duplicate_import_ids == o.duplicate_import_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


102
103
104
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 102

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



108
109
110
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 108

def hash
  [transaction_ids, duplicate_import_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



78
79
80
81
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 78

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 137

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



85
86
87
88
89
# File 'lib/ynab/models/bulk_response_data_bulk.rb', line 85

def valid?
  return false if @transaction_ids.nil?
  return false if @duplicate_import_ids.nil?
  true
end