Class: YNAB::CategoryGroup
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::CategoryGroup
- Defined in:
- lib/ynab/models/category_group.rb
Instance Attribute Summary collapse
-
#deleted ⇒ Object
Whether or not the category group has been deleted.
-
#hidden ⇒ Object
Whether or not the category group is hidden.
-
#id ⇒ Object
Returns the value of attribute id.
-
#internal ⇒ Object
Whether or not the category group is internal.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CategoryGroup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CategoryGroup
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/ynab/models/category_group.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::CategoryGroup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::CategoryGroup`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'hidden') self.hidden = attributes[:'hidden'] end if attributes.key?(:'internal') self.internal = attributes[:'internal'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end end |
Instance Attribute Details
#deleted ⇒ Object
Whether or not the category group has been deleted. Deleted category groups will only be included in delta requests.
26 27 28 |
# File 'lib/ynab/models/category_group.rb', line 26 def deleted @deleted end |
#hidden ⇒ Object
Whether or not the category group is hidden
20 21 22 |
# File 'lib/ynab/models/category_group.rb', line 20 def hidden @hidden end |
#id ⇒ Object
Returns the value of attribute id.
15 16 17 |
# File 'lib/ynab/models/category_group.rb', line 15 def id @id end |
#internal ⇒ Object
Whether or not the category group is internal
23 24 25 |
# File 'lib/ynab/models/category_group.rb', line 23 def internal @internal end |
#name ⇒ Object
Returns the value of attribute name.
17 18 19 |
# File 'lib/ynab/models/category_group.rb', line 17 def name @name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/ynab/models/category_group.rb', line 40 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/ynab/models/category_group.rb', line 29 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'hidden' => :'hidden', :'internal' => :'internal', :'deleted' => :'deleted' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/ynab/models/category_group.rb', line 142 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/ynab/models/category_group.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 |
# File 'lib/ynab/models/category_group.rb', line 45 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'hidden' => :'Boolean', :'internal' => :'Boolean', :'deleted' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 |
# File 'lib/ynab/models/category_group.rb', line 117 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && hidden == o.hidden && internal == o.internal && deleted == o.deleted end |
#eql?(o) ⇒ Boolean
129 130 131 |
# File 'lib/ynab/models/category_group.rb', line 129 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
135 136 137 |
# File 'lib/ynab/models/category_group.rb', line 135 def hash [id, name, hidden, internal, deleted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
99 100 101 102 |
# File 'lib/ynab/models/category_group.rb', line 99 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/ynab/models/category_group.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 110 111 112 113 |
# File 'lib/ynab/models/category_group.rb', line 106 def valid? return false if @id.nil? return false if @name.nil? return false if @hidden.nil? return false if @internal.nil? return false if @deleted.nil? true end |