Class: YNAB::CategoryGroupWithCategories

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/category_group_with_categories.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CategoryGroupWithCategories

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/ynab/models/category_group_with_categories.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::CategoryGroupWithCategories` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::CategoryGroupWithCategories`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'hidden')
    self.hidden = attributes[:'hidden']
  end

  if attributes.key?(:'internal')
    self.internal = attributes[:'internal']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'categories')
    if (value = attributes[:'categories']).is_a?(Array)
      self.categories = value
    end
  end
end

Instance Attribute Details

#categoriesObject

Category group categories. Amounts (assigned, activity, available, etc.) are specific to the current plan month (UTC).



29
30
31
# File 'lib/ynab/models/category_group_with_categories.rb', line 29

def categories
  @categories
end

#deletedObject

Whether or not the category group has been deleted. Deleted category groups will only be included in delta requests.



26
27
28
# File 'lib/ynab/models/category_group_with_categories.rb', line 26

def deleted
  @deleted
end

#hiddenObject

Whether or not the category group is hidden



20
21
22
# File 'lib/ynab/models/category_group_with_categories.rb', line 20

def hidden
  @hidden
end

#idObject

Returns the value of attribute id.



15
16
17
# File 'lib/ynab/models/category_group_with_categories.rb', line 15

def id
  @id
end

#internalObject

Whether or not the category group is internal



23
24
25
# File 'lib/ynab/models/category_group_with_categories.rb', line 23

def internal
  @internal
end

#nameObject

Returns the value of attribute name.



17
18
19
# File 'lib/ynab/models/category_group_with_categories.rb', line 17

def name
  @name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/ynab/models/category_group_with_categories.rb', line 44

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/ynab/models/category_group_with_categories.rb', line 32

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'hidden' => :'hidden',
    :'internal' => :'internal',
    :'deleted' => :'deleted',
    :'categories' => :'categories'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/ynab/models/category_group_with_categories.rb', line 162

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



67
68
69
70
71
# File 'lib/ynab/models/category_group_with_categories.rb', line 67

def self.openapi_all_of
  [
  :'CategoryGroup'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/ynab/models/category_group_with_categories.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
58
# File 'lib/ynab/models/category_group_with_categories.rb', line 49

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'hidden' => :'Boolean',
    :'internal' => :'Boolean',
    :'deleted' => :'Boolean',
    :'categories' => :'Array<Category>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



136
137
138
139
140
141
142
143
144
145
# File 'lib/ynab/models/category_group_with_categories.rb', line 136

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      hidden == o.hidden &&
      internal == o.internal &&
      deleted == o.deleted &&
      categories == o.categories
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


149
150
151
# File 'lib/ynab/models/category_group_with_categories.rb', line 149

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



155
156
157
# File 'lib/ynab/models/category_group_with_categories.rb', line 155

def hash
  [id, name, hidden, internal, deleted, categories].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
# File 'lib/ynab/models/category_group_with_categories.rb', line 117

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/ynab/models/category_group_with_categories.rb', line 184

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
128
129
130
131
132
# File 'lib/ynab/models/category_group_with_categories.rb', line 124

def valid?
  return false if @id.nil?
  return false if @name.nil?
  return false if @hidden.nil?
  return false if @internal.nil?
  return false if @deleted.nil?
  return false if @categories.nil?
  true
end