Class: YNAB::CurrencyFormat

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/currency_format.rb

Overview

The currency format setting for the plan. In some cases the format will not be available and will be specified as null.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CurrencyFormat

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/ynab/models/currency_format.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::CurrencyFormat` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::CurrencyFormat`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'iso_code')
    self.iso_code = attributes[:'iso_code']
  end

  if attributes.key?(:'example_format')
    self.example_format = attributes[:'example_format']
  end

  if attributes.key?(:'decimal_digits')
    self.decimal_digits = attributes[:'decimal_digits']
  end

  if attributes.key?(:'decimal_separator')
    self.decimal_separator = attributes[:'decimal_separator']
  end

  if attributes.key?(:'symbol_first')
    self.symbol_first = attributes[:'symbol_first']
  end

  if attributes.key?(:'group_separator')
    self.group_separator = attributes[:'group_separator']
  end

  if attributes.key?(:'currency_symbol')
    self.currency_symbol = attributes[:'currency_symbol']
  end

  if attributes.key?(:'display_symbol')
    self.display_symbol = attributes[:'display_symbol']
  end
end

Instance Attribute Details

#currency_symbolObject

Returns the value of attribute currency_symbol.



28
29
30
# File 'lib/ynab/models/currency_format.rb', line 28

def currency_symbol
  @currency_symbol
end

#decimal_digitsObject

Returns the value of attribute decimal_digits.



20
21
22
# File 'lib/ynab/models/currency_format.rb', line 20

def decimal_digits
  @decimal_digits
end

#decimal_separatorObject

Returns the value of attribute decimal_separator.



22
23
24
# File 'lib/ynab/models/currency_format.rb', line 22

def decimal_separator
  @decimal_separator
end

#display_symbolObject

Returns the value of attribute display_symbol.



30
31
32
# File 'lib/ynab/models/currency_format.rb', line 30

def display_symbol
  @display_symbol
end

#example_formatObject

Returns the value of attribute example_format.



18
19
20
# File 'lib/ynab/models/currency_format.rb', line 18

def example_format
  @example_format
end

#group_separatorObject

Returns the value of attribute group_separator.



26
27
28
# File 'lib/ynab/models/currency_format.rb', line 26

def group_separator
  @group_separator
end

#iso_codeObject

Returns the value of attribute iso_code.



16
17
18
# File 'lib/ynab/models/currency_format.rb', line 16

def iso_code
  @iso_code
end

#symbol_firstObject

Returns the value of attribute symbol_first.



24
25
26
# File 'lib/ynab/models/currency_format.rb', line 24

def symbol_first
  @symbol_first
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/ynab/models/currency_format.rb', line 47

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/ynab/models/currency_format.rb', line 33

def self.attribute_map
  {
    :'iso_code' => :'iso_code',
    :'example_format' => :'example_format',
    :'decimal_digits' => :'decimal_digits',
    :'decimal_separator' => :'decimal_separator',
    :'symbol_first' => :'symbol_first',
    :'group_separator' => :'group_separator',
    :'currency_symbol' => :'currency_symbol',
    :'display_symbol' => :'display_symbol'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/ynab/models/currency_format.rb', line 170

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/ynab/models/currency_format.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/ynab/models/currency_format.rb', line 52

def self.openapi_types
  {
    :'iso_code' => :'String',
    :'example_format' => :'String',
    :'decimal_digits' => :'Integer',
    :'decimal_separator' => :'String',
    :'symbol_first' => :'Boolean',
    :'group_separator' => :'String',
    :'currency_symbol' => :'String',
    :'display_symbol' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/ynab/models/currency_format.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      iso_code == o.iso_code &&
      example_format == o.example_format &&
      decimal_digits == o.decimal_digits &&
      decimal_separator == o.decimal_separator &&
      symbol_first == o.symbol_first &&
      group_separator == o.group_separator &&
      currency_symbol == o.currency_symbol &&
      display_symbol == o.display_symbol
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/ynab/models/currency_format.rb', line 157

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



163
164
165
# File 'lib/ynab/models/currency_format.rb', line 163

def hash
  [iso_code, example_format, decimal_digits, decimal_separator, symbol_first, group_separator, currency_symbol, display_symbol].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
# File 'lib/ynab/models/currency_format.rb', line 121

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/ynab/models/currency_format.rb', line 192

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/ynab/models/currency_format.rb', line 128

def valid?
  return false if @iso_code.nil?
  return false if @example_format.nil?
  return false if @decimal_digits.nil?
  return false if @decimal_separator.nil?
  return false if @symbol_first.nil?
  return false if @group_separator.nil?
  return false if @currency_symbol.nil?
  return false if @display_symbol.nil?
  true
end