Class: YNAB::DateFormat

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/date_format.rb

Overview

The date format setting for the plan. In some cases the format will not be available and will be specified as null.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DateFormat

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/ynab/models/date_format.rb', line 45

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::DateFormat` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::DateFormat`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end
end

Instance Attribute Details

#formatObject

Returns the value of attribute format.



16
17
18
# File 'lib/ynab/models/date_format.rb', line 16

def format
  @format
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



26
27
28
# File 'lib/ynab/models/date_format.rb', line 26

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



19
20
21
22
23
# File 'lib/ynab/models/date_format.rb', line 19

def self.attribute_map
  {
    :'format' => :'format'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/ynab/models/date_format.rb', line 100

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



38
39
40
41
# File 'lib/ynab/models/date_format.rb', line 38

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



31
32
33
34
35
# File 'lib/ynab/models/date_format.rb', line 31

def self.openapi_types
  {
    :'format' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



79
80
81
82
83
# File 'lib/ynab/models/date_format.rb', line 79

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      format == o.format
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


87
88
89
# File 'lib/ynab/models/date_format.rb', line 87

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



93
94
95
# File 'lib/ynab/models/date_format.rb', line 93

def hash
  [format].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



65
66
67
68
# File 'lib/ynab/models/date_format.rb', line 65

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/ynab/models/date_format.rb', line 122

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



72
73
74
75
# File 'lib/ynab/models/date_format.rb', line 72

def valid?
  return false if @format.nil?
  true
end