Class: YNAB::ErrorDetail

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/error_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ErrorDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/ynab/models/error_detail.rb', line 52

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::ErrorDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::ErrorDetail`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'detail')
    self.detail = attributes[:'detail']
  end
end

Instance Attribute Details

#detailObject

Returns the value of attribute detail.



19
20
21
# File 'lib/ynab/models/error_detail.rb', line 19

def detail
  @detail
end

#idObject

Returns the value of attribute id.



15
16
17
# File 'lib/ynab/models/error_detail.rb', line 15

def id
  @id
end

#nameObject

Returns the value of attribute name.



17
18
19
# File 'lib/ynab/models/error_detail.rb', line 17

def name
  @name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



31
32
33
# File 'lib/ynab/models/error_detail.rb', line 31

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



22
23
24
25
26
27
28
# File 'lib/ynab/models/error_detail.rb', line 22

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'detail' => :'detail'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/ynab/models/error_detail.rb', line 119

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



45
46
47
48
# File 'lib/ynab/models/error_detail.rb', line 45

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



36
37
38
39
40
41
42
# File 'lib/ynab/models/error_detail.rb', line 36

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'detail' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



96
97
98
99
100
101
102
# File 'lib/ynab/models/error_detail.rb', line 96

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      detail == o.detail
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


106
107
108
# File 'lib/ynab/models/error_detail.rb', line 106

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



112
113
114
# File 'lib/ynab/models/error_detail.rb', line 112

def hash
  [id, name, detail].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



80
81
82
83
# File 'lib/ynab/models/error_detail.rb', line 80

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/ynab/models/error_detail.rb', line 141

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



87
88
89
90
91
92
# File 'lib/ynab/models/error_detail.rb', line 87

def valid?
  return false if @id.nil?
  return false if @name.nil?
  return false if @detail.nil?
  true
end