Class: YNAB::ExistingTransaction

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/existing_transaction.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExistingTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/ynab/models/existing_transaction.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::ExistingTransaction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::ExistingTransaction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'payee_id')
    self.payee_id = attributes[:'payee_id']
  end

  if attributes.key?(:'payee_name')
    self.payee_name = attributes[:'payee_name']
  end

  if attributes.key?(:'category_id')
    self.category_id = attributes[:'category_id']
  end

  if attributes.key?(:'memo')
    self.memo = attributes[:'memo']
  end

  if attributes.key?(:'cleared')
    self.cleared = attributes[:'cleared']
  end

  if attributes.key?(:'approved')
    self.approved = attributes[:'approved']
  end

  if attributes.key?(:'flag_color')
    self.flag_color = attributes[:'flag_color']
  end

  if attributes.key?(:'subtransactions')
    if (value = attributes[:'subtransactions']).is_a?(Array)
      self.subtransactions = value
    end
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



15
16
17
# File 'lib/ynab/models/existing_transaction.rb', line 15

def 
  @account_id
end

#amountObject

The transaction amount in milliunits format. Split transaction amounts cannot be changed and if a different amount is supplied it will be ignored.



21
22
23
# File 'lib/ynab/models/existing_transaction.rb', line 21

def amount
  @amount
end

#approvedObject

Whether or not the transaction is approved. If not supplied, transaction will be unapproved by default.



37
38
39
# File 'lib/ynab/models/existing_transaction.rb', line 37

def approved
  @approved
end

#category_idObject

The category for the transaction. To configure a split transaction, you can specify null for category_id and provide a subtransactions array as part of the transaction object. If an existing transaction is a split, the category_id cannot be changed. Credit Card Payment categories are not permitted and will be ignored if supplied.



30
31
32
# File 'lib/ynab/models/existing_transaction.rb', line 30

def category_id
  @category_id
end

#clearedObject

Returns the value of attribute cleared.



34
35
36
# File 'lib/ynab/models/existing_transaction.rb', line 34

def cleared
  @cleared
end

#dateObject

The transaction date in ISO format (e.g. 2016-12-01). Future dates (scheduled transactions) are not permitted. Split transaction dates cannot be changed and if a different date is supplied it will be ignored.



18
19
20
# File 'lib/ynab/models/existing_transaction.rb', line 18

def date
  @date
end

#flag_colorObject

Returns the value of attribute flag_color.



39
40
41
# File 'lib/ynab/models/existing_transaction.rb', line 39

def flag_color
  @flag_color
end

#memoObject

Returns the value of attribute memo.



32
33
34
# File 'lib/ynab/models/existing_transaction.rb', line 32

def memo
  @memo
end

#payee_idObject

The payee for the transaction. To create a transfer between two accounts, use the account transfer payee pointing to the target account. Account transfer payees are specified as transfer_payee_id on the account resource.



24
25
26
# File 'lib/ynab/models/existing_transaction.rb', line 24

def payee_id
  @payee_id
end

#payee_nameObject

The payee name. If a payee_name value is provided and payee_id has a null value, the payee_name value will be used to resolve the payee by either (1) a matching payee rename rule (only if import_id is also specified) or (2) a payee with the same name or (3) creation of a new payee.



27
28
29
# File 'lib/ynab/models/existing_transaction.rb', line 27

def payee_name
  @payee_name
end

#subtransactionsObject

An array of subtransactions to configure a transaction as a split. Updating subtransactions on an existing split transaction is not supported.



42
43
44
# File 'lib/ynab/models/existing_transaction.rb', line 42

def subtransactions
  @subtransactions
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/ynab/models/existing_transaction.rb', line 84

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/ynab/models/existing_transaction.rb', line 67

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'date' => :'date',
    :'amount' => :'amount',
    :'payee_id' => :'payee_id',
    :'payee_name' => :'payee_name',
    :'category_id' => :'category_id',
    :'memo' => :'memo',
    :'cleared' => :'cleared',
    :'approved' => :'approved',
    :'flag_color' => :'flag_color',
    :'subtransactions' => :'subtransactions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/ynab/models/existing_transaction.rb', line 241

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



113
114
115
116
117
# File 'lib/ynab/models/existing_transaction.rb', line 113

def self.openapi_all_of
  [
  :'SaveTransactionWithOptionalFields'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
110
# File 'lib/ynab/models/existing_transaction.rb', line 106

def self.openapi_nullable
  Set.new([
    :'flag_color',
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/ynab/models/existing_transaction.rb', line 89

def self.openapi_types
  {
    :'account_id' => :'String',
    :'date' => :'Date',
    :'amount' => :'Integer',
    :'payee_id' => :'String',
    :'payee_name' => :'String',
    :'category_id' => :'String',
    :'memo' => :'String',
    :'cleared' => :'TransactionClearedStatus',
    :'approved' => :'Boolean',
    :'flag_color' => :'TransactionFlagColor',
    :'subtransactions' => :'Array<SaveSubTransaction>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/ynab/models/existing_transaction.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      date == o.date &&
      amount == o.amount &&
      payee_id == o.payee_id &&
      payee_name == o.payee_name &&
      category_id == o.category_id &&
      memo == o.memo &&
      cleared == o.cleared &&
      approved == o.approved &&
      flag_color == o.flag_color &&
      subtransactions == o.subtransactions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


228
229
230
# File 'lib/ynab/models/existing_transaction.rb', line 228

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



234
235
236
# File 'lib/ynab/models/existing_transaction.rb', line 234

def hash
  [, date, amount, payee_id, payee_name, category_id, memo, cleared, approved, flag_color, subtransactions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
# File 'lib/ynab/models/existing_transaction.rb', line 183

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/ynab/models/existing_transaction.rb', line 263

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
# File 'lib/ynab/models/existing_transaction.rb', line 190

def valid?
  return false if !@payee_name.nil? && @payee_name.to_s.length > 200
  return false if !@memo.nil? && @memo.to_s.length > 500
  true
end