Class: YNAB::HybridTransaction
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::HybridTransaction
- Defined in:
- lib/ynab/models/hybrid_transaction.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_name ⇒ Object
Returns the value of attribute account_name.
-
#amount ⇒ Object
The transaction amount in milliunits format.
-
#amount_currency ⇒ Object
The transaction amount as a decimal currency amount.
-
#amount_formatted ⇒ Object
The transaction amount formatted in the plan’s currency format.
-
#approved ⇒ Object
Whether or not the transaction is approved.
-
#category_id ⇒ Object
Returns the value of attribute category_id.
-
#category_name ⇒ Object
The name of the category.
-
#cleared ⇒ Object
Returns the value of attribute cleared.
-
#date ⇒ Object
The transaction date in ISO format (e.g. 2016-12-01).
-
#debt_transaction_type ⇒ Object
If the transaction is a debt/loan account transaction, the type of transaction.
-
#deleted ⇒ Object
Whether or not the transaction has been deleted.
-
#flag_color ⇒ Object
Returns the value of attribute flag_color.
-
#flag_name ⇒ Object
The customized name of a transaction flag.
-
#id ⇒ Object
Returns the value of attribute id.
-
#import_id ⇒ Object
If the transaction was imported, this field is a unique (by account) import identifier.
-
#import_payee_name ⇒ Object
If the transaction was imported, the payee name that was used when importing and before applying any payee rename rules.
-
#import_payee_name_original ⇒ Object
If the transaction was imported, the original payee name as it appeared on the statement.
-
#matched_transaction_id ⇒ Object
If transaction is matched, the id of the matched transaction.
-
#memo ⇒ Object
Returns the value of attribute memo.
-
#parent_transaction_id ⇒ Object
For subtransaction types, this is the id of the parent transaction.
-
#payee_id ⇒ Object
Returns the value of attribute payee_id.
-
#payee_name ⇒ Object
Returns the value of attribute payee_name.
-
#transfer_account_id ⇒ Object
If a transfer transaction, the account to which it transfers.
-
#transfer_transaction_id ⇒ Object
If a transfer transaction, the id of transaction on the other side of the transfer.
-
#type ⇒ Object
Whether the hybrid transaction represents a regular transaction or a subtransaction.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HybridTransaction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ HybridTransaction
Initializes the object
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 194 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::HybridTransaction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::HybridTransaction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'memo') self.memo = attributes[:'memo'] end if attributes.key?(:'cleared') self.cleared = attributes[:'cleared'] end if attributes.key?(:'approved') self.approved = attributes[:'approved'] end if attributes.key?(:'flag_color') self.flag_color = attributes[:'flag_color'] end if attributes.key?(:'flag_name') self.flag_name = attributes[:'flag_name'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'payee_id') self.payee_id = attributes[:'payee_id'] end if attributes.key?(:'category_id') self.category_id = attributes[:'category_id'] end if attributes.key?(:'transfer_account_id') self.transfer_account_id = attributes[:'transfer_account_id'] end if attributes.key?(:'transfer_transaction_id') self.transfer_transaction_id = attributes[:'transfer_transaction_id'] end if attributes.key?(:'matched_transaction_id') self.matched_transaction_id = attributes[:'matched_transaction_id'] end if attributes.key?(:'import_id') self.import_id = attributes[:'import_id'] end if attributes.key?(:'import_payee_name') self.import_payee_name = attributes[:'import_payee_name'] end if attributes.key?(:'import_payee_name_original') self.import_payee_name_original = attributes[:'import_payee_name_original'] end if attributes.key?(:'debt_transaction_type') self.debt_transaction_type = attributes[:'debt_transaction_type'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'amount_formatted') self.amount_formatted = attributes[:'amount_formatted'] end if attributes.key?(:'amount_currency') self.amount_currency = attributes[:'amount_currency'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'parent_transaction_id') self.parent_transaction_id = attributes[:'parent_transaction_id'] end if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'payee_name') self.payee_name = attributes[:'payee_name'] end if attributes.key?(:'category_name') self.category_name = attributes[:'category_name'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
35 36 37 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 35 def account_id @account_id end |
#account_name ⇒ Object
Returns the value of attribute account_name.
77 78 79 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 77 def account_name @account_name end |
#amount ⇒ Object
The transaction amount in milliunits format
21 22 23 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 21 def amount @amount end |
#amount_currency ⇒ Object
The transaction amount as a decimal currency amount
69 70 71 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 69 def amount_currency @amount_currency end |
#amount_formatted ⇒ Object
The transaction amount formatted in the plan’s currency format
66 67 68 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 66 def amount_formatted @amount_formatted end |
#approved ⇒ Object
Whether or not the transaction is approved
28 29 30 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 28 def approved @approved end |
#category_id ⇒ Object
Returns the value of attribute category_id.
39 40 41 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 39 def category_id @category_id end |
#category_name ⇒ Object
The name of the category. If a split transaction, this will be ‘Split’.
82 83 84 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 82 def category_name @category_name end |
#cleared ⇒ Object
Returns the value of attribute cleared.
25 26 27 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 25 def cleared @cleared end |
#date ⇒ Object
The transaction date in ISO format (e.g. 2016-12-01)
18 19 20 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 18 def date @date end |
#debt_transaction_type ⇒ Object
If the transaction is a debt/loan account transaction, the type of transaction
60 61 62 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 60 def debt_transaction_type @debt_transaction_type end |
#deleted ⇒ Object
Whether or not the transaction has been deleted. Deleted transactions will only be included in delta requests.
63 64 65 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 63 def deleted @deleted end |
#flag_color ⇒ Object
Returns the value of attribute flag_color.
30 31 32 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 30 def flag_color @flag_color end |
#flag_name ⇒ Object
The customized name of a transaction flag
33 34 35 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 33 def flag_name @flag_name end |
#id ⇒ Object
Returns the value of attribute id.
15 16 17 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 15 def id @id end |
#import_id ⇒ Object
If the transaction was imported, this field is a unique (by account) import identifier. If this transaction was imported through File Based Import or Direct Import and not through the API, the import_id will have the format: ‘YNAB::[iso_date]:’. For example, a transaction dated 2015-12-30 in the amount of -$294.23 USD would have an import_id of ‘YNAB:-294230:2015-12-30:1’. If a second transaction on the same account was imported and had the same date and same amount, its import_id would be ‘YNAB:-294230:2015-12-30:2’.
51 52 53 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 51 def import_id @import_id end |
#import_payee_name ⇒ Object
If the transaction was imported, the payee name that was used when importing and before applying any payee rename rules
54 55 56 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 54 def import_payee_name @import_payee_name end |
#import_payee_name_original ⇒ Object
If the transaction was imported, the original payee name as it appeared on the statement
57 58 59 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 57 def import_payee_name_original @import_payee_name_original end |
#matched_transaction_id ⇒ Object
If transaction is matched, the id of the matched transaction
48 49 50 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 48 def matched_transaction_id @matched_transaction_id end |
#memo ⇒ Object
Returns the value of attribute memo.
23 24 25 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 23 def memo @memo end |
#parent_transaction_id ⇒ Object
For subtransaction types, this is the id of the parent transaction. For transaction types, this id will be always be null.
75 76 77 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 75 def parent_transaction_id @parent_transaction_id end |
#payee_id ⇒ Object
Returns the value of attribute payee_id.
37 38 39 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 37 def payee_id @payee_id end |
#payee_name ⇒ Object
Returns the value of attribute payee_name.
79 80 81 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 79 def payee_name @payee_name end |
#transfer_account_id ⇒ Object
If a transfer transaction, the account to which it transfers
42 43 44 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 42 def transfer_account_id @transfer_account_id end |
#transfer_transaction_id ⇒ Object
If a transfer transaction, the id of transaction on the other side of the transfer
45 46 47 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 45 def transfer_transaction_id @transfer_transaction_id end |
#type ⇒ Object
Whether the hybrid transaction represents a regular transaction or a subtransaction
72 73 74 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 72 def type @type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
139 140 141 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 139 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 107 def self.attribute_map { :'id' => :'id', :'date' => :'date', :'amount' => :'amount', :'memo' => :'memo', :'cleared' => :'cleared', :'approved' => :'approved', :'flag_color' => :'flag_color', :'flag_name' => :'flag_name', :'account_id' => :'account_id', :'payee_id' => :'payee_id', :'category_id' => :'category_id', :'transfer_account_id' => :'transfer_account_id', :'transfer_transaction_id' => :'transfer_transaction_id', :'matched_transaction_id' => :'matched_transaction_id', :'import_id' => :'import_id', :'import_payee_name' => :'import_payee_name', :'import_payee_name_original' => :'import_payee_name_original', :'debt_transaction_type' => :'debt_transaction_type', :'deleted' => :'deleted', :'amount_formatted' => :'amount_formatted', :'amount_currency' => :'amount_currency', :'type' => :'type', :'parent_transaction_id' => :'parent_transaction_id', :'account_name' => :'account_name', :'payee_name' => :'payee_name', :'category_name' => :'category_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 398 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
186 187 188 189 190 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 186 def self.openapi_all_of [ :'TransactionSummary' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
176 177 178 179 180 181 182 183 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 176 def self.openapi_nullable Set.new([ :'flag_color', :'debt_transaction_type', :'parent_transaction_id', :'payee_name', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 144 def self.openapi_types { :'id' => :'String', :'date' => :'Date', :'amount' => :'Integer', :'memo' => :'String', :'cleared' => :'TransactionClearedStatus', :'approved' => :'Boolean', :'flag_color' => :'TransactionFlagColor', :'flag_name' => :'String', :'account_id' => :'String', :'payee_id' => :'String', :'category_id' => :'String', :'transfer_account_id' => :'String', :'transfer_transaction_id' => :'String', :'matched_transaction_id' => :'String', :'import_id' => :'String', :'import_payee_name' => :'String', :'import_payee_name_original' => :'String', :'debt_transaction_type' => :'String', :'deleted' => :'Boolean', :'amount_formatted' => :'String', :'amount_currency' => :'Float', :'type' => :'String', :'parent_transaction_id' => :'String', :'account_name' => :'String', :'payee_name' => :'String', :'category_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 352 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && date == o.date && amount == o.amount && memo == o.memo && cleared == o.cleared && approved == o.approved && flag_color == o.flag_color && flag_name == o.flag_name && account_id == o.account_id && payee_id == o.payee_id && category_id == o.category_id && transfer_account_id == o.transfer_account_id && transfer_transaction_id == o.transfer_transaction_id && matched_transaction_id == o.matched_transaction_id && import_id == o.import_id && import_payee_name == o.import_payee_name && import_payee_name_original == o.import_payee_name_original && debt_transaction_type == o.debt_transaction_type && deleted == o.deleted && amount_formatted == o.amount_formatted && amount_currency == o.amount_currency && type == o.type && parent_transaction_id == o.parent_transaction_id && account_name == o.account_name && payee_name == o.payee_name && category_name == o.category_name end |
#eql?(o) ⇒ Boolean
385 386 387 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 385 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
391 392 393 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 391 def hash [id, date, amount, memo, cleared, approved, flag_color, flag_name, account_id, payee_id, category_id, transfer_account_id, transfer_transaction_id, matched_transaction_id, import_id, import_payee_name, import_payee_name_original, debt_transaction_type, deleted, amount_formatted, amount_currency, type, parent_transaction_id, account_name, payee_name, category_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
314 315 316 317 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 314 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 420 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/ynab/models/hybrid_transaction.rb', line 321 def valid? return false if @id.nil? return false if @date.nil? return false if @amount.nil? return false if @cleared.nil? return false if @approved.nil? return false if @account_id.nil? debt_transaction_type_validator = EnumAttributeValidator.new('String', ["payment", "refund", "fee", "interest", "escrow", "balanceAdjustment", "credit", "charge"]) return false unless debt_transaction_type_validator.valid?(@debt_transaction_type) return false if @deleted.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["transaction", "subtransaction"]) return false unless type_validator.valid?(@type) return false if @account_name.nil? true end |