Class: YNAB::MoneyMovementsResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::MoneyMovementsResponse
- Defined in:
- lib/ynab/models/money_movements_response.rb
Instance Attribute Summary collapse
-
#data ⇒ Object
Returns the value of attribute data.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MoneyMovementsResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MoneyMovementsResponse
Initializes the object
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/ynab/models/money_movements_response.rb', line 44 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::MoneyMovementsResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::MoneyMovementsResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'data') self.data = attributes[:'data'] end end |
Instance Attribute Details
#data ⇒ Object
Returns the value of attribute data.
15 16 17 |
# File 'lib/ynab/models/money_movements_response.rb', line 15 def data @data end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
25 26 27 |
# File 'lib/ynab/models/money_movements_response.rb', line 25 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 |
# File 'lib/ynab/models/money_movements_response.rb', line 18 def self.attribute_map { :'data' => :'data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/ynab/models/money_movements_response.rb', line 99 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
37 38 39 40 |
# File 'lib/ynab/models/money_movements_response.rb', line 37 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
30 31 32 33 34 |
# File 'lib/ynab/models/money_movements_response.rb', line 30 def self.openapi_types { :'data' => :'MoneyMovementsResponseData' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
78 79 80 81 82 |
# File 'lib/ynab/models/money_movements_response.rb', line 78 def ==(o) return true if self.equal?(o) self.class == o.class && data == o.data end |
#eql?(o) ⇒ Boolean
86 87 88 |
# File 'lib/ynab/models/money_movements_response.rb', line 86 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
92 93 94 |
# File 'lib/ynab/models/money_movements_response.rb', line 92 def hash [data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
64 65 66 67 |
# File 'lib/ynab/models/money_movements_response.rb', line 64 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/ynab/models/money_movements_response.rb', line 121 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
71 72 73 74 |
# File 'lib/ynab/models/money_movements_response.rb', line 71 def valid? return false if @data.nil? true end |