Class: YNAB::MonthSummary

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/month_summary.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MonthSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/ynab/models/month_summary.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::MonthSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::MonthSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'month')
    self.month = attributes[:'month']
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end

  if attributes.key?(:'income')
    self.income = attributes[:'income']
  end

  if attributes.key?(:'budgeted')
    self.budgeted = attributes[:'budgeted']
  end

  if attributes.key?(:'activity')
    self.activity = attributes[:'activity']
  end

  if attributes.key?(:'to_be_budgeted')
    self.to_be_budgeted = attributes[:'to_be_budgeted']
  end

  if attributes.key?(:'age_of_money')
    self.age_of_money = attributes[:'age_of_money']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end
end

Instance Attribute Details

#activityObject

The total amount of transactions in the month, excluding those categorized to ‘Inflow: Ready to Assign’



26
27
28
# File 'lib/ynab/models/month_summary.rb', line 26

def activity
  @activity
end

#age_of_moneyObject

The Age of Money as of the month



32
33
34
# File 'lib/ynab/models/month_summary.rb', line 32

def age_of_money
  @age_of_money
end

#budgetedObject

The total amount assigned (budgeted) in the month



23
24
25
# File 'lib/ynab/models/month_summary.rb', line 23

def budgeted
  @budgeted
end

#deletedObject

Whether or not the month has been deleted. Deleted months will only be included in delta requests.



35
36
37
# File 'lib/ynab/models/month_summary.rb', line 35

def deleted
  @deleted
end

#incomeObject

The total amount of transactions categorized to ‘Inflow: Ready to Assign’ in the month



20
21
22
# File 'lib/ynab/models/month_summary.rb', line 20

def income
  @income
end

#monthObject

Returns the value of attribute month.



15
16
17
# File 'lib/ynab/models/month_summary.rb', line 15

def month
  @month
end

#noteObject

Returns the value of attribute note.



17
18
19
# File 'lib/ynab/models/month_summary.rb', line 17

def note
  @note
end

#to_be_budgetedObject

The available amount for ‘Ready to Assign’



29
30
31
# File 'lib/ynab/models/month_summary.rb', line 29

def to_be_budgeted
  @to_be_budgeted
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/ynab/models/month_summary.rb', line 52

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/ynab/models/month_summary.rb', line 38

def self.attribute_map
  {
    :'month' => :'month',
    :'note' => :'note',
    :'income' => :'income',
    :'budgeted' => :'budgeted',
    :'activity' => :'activity',
    :'to_be_budgeted' => :'to_be_budgeted',
    :'age_of_money' => :'age_of_money',
    :'deleted' => :'deleted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/ynab/models/month_summary.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
75
76
# File 'lib/ynab/models/month_summary.rb', line 71

def self.openapi_nullable
  Set.new([
    :'note',
    :'age_of_money',
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/ynab/models/month_summary.rb', line 57

def self.openapi_types
  {
    :'month' => :'Date',
    :'note' => :'String',
    :'income' => :'Integer',
    :'budgeted' => :'Integer',
    :'activity' => :'Integer',
    :'to_be_budgeted' => :'Integer',
    :'age_of_money' => :'Integer',
    :'deleted' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/ynab/models/month_summary.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      month == o.month &&
      note == o.note &&
      income == o.income &&
      budgeted == o.budgeted &&
      activity == o.activity &&
      to_be_budgeted == o.to_be_budgeted &&
      age_of_money == o.age_of_money &&
      deleted == o.deleted
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/ynab/models/month_summary.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



168
169
170
# File 'lib/ynab/models/month_summary.rb', line 168

def hash
  [month, note, income, budgeted, activity, to_be_budgeted, age_of_money, deleted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
# File 'lib/ynab/models/month_summary.rb', line 128

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/ynab/models/month_summary.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
140
141
142
143
# File 'lib/ynab/models/month_summary.rb', line 135

def valid?
  return false if @month.nil?
  return false if @income.nil?
  return false if @budgeted.nil?
  return false if @activity.nil?
  return false if @to_be_budgeted.nil?
  return false if @deleted.nil?
  true
end