Class: YNAB::NewTransaction

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/new_transaction.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/ynab/models/new_transaction.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::NewTransaction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::NewTransaction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'payee_id')
    self.payee_id = attributes[:'payee_id']
  end

  if attributes.key?(:'payee_name')
    self.payee_name = attributes[:'payee_name']
  end

  if attributes.key?(:'category_id')
    self.category_id = attributes[:'category_id']
  end

  if attributes.key?(:'memo')
    self.memo = attributes[:'memo']
  end

  if attributes.key?(:'cleared')
    self.cleared = attributes[:'cleared']
  end

  if attributes.key?(:'approved')
    self.approved = attributes[:'approved']
  end

  if attributes.key?(:'flag_color')
    self.flag_color = attributes[:'flag_color']
  end

  if attributes.key?(:'subtransactions')
    if (value = attributes[:'subtransactions']).is_a?(Array)
      self.subtransactions = value
    end
  end

  if attributes.key?(:'import_id')
    self.import_id = attributes[:'import_id']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



15
16
17
# File 'lib/ynab/models/new_transaction.rb', line 15

def 
  @account_id
end

#amountObject

The transaction amount in milliunits format. Split transaction amounts cannot be changed and if a different amount is supplied it will be ignored.



21
22
23
# File 'lib/ynab/models/new_transaction.rb', line 21

def amount
  @amount
end

#approvedObject

Whether or not the transaction is approved. If not supplied, transaction will be unapproved by default.



37
38
39
# File 'lib/ynab/models/new_transaction.rb', line 37

def approved
  @approved
end

#category_idObject

The category for the transaction. To configure a split transaction, you can specify null for category_id and provide a subtransactions array as part of the transaction object. If an existing transaction is a split, the category_id cannot be changed. Credit Card Payment categories are not permitted and will be ignored if supplied.



30
31
32
# File 'lib/ynab/models/new_transaction.rb', line 30

def category_id
  @category_id
end

#clearedObject

Returns the value of attribute cleared.



34
35
36
# File 'lib/ynab/models/new_transaction.rb', line 34

def cleared
  @cleared
end

#dateObject

The transaction date in ISO format (e.g. 2016-12-01). Future dates (scheduled transactions) are not permitted. Split transaction dates cannot be changed and if a different date is supplied it will be ignored.



18
19
20
# File 'lib/ynab/models/new_transaction.rb', line 18

def date
  @date
end

#flag_colorObject

Returns the value of attribute flag_color.



39
40
41
# File 'lib/ynab/models/new_transaction.rb', line 39

def flag_color
  @flag_color
end

#import_idObject

If specified, a new transaction will be assigned this import_id and considered "imported". We will also attempt to match this imported transaction to an existing "user-entered" transaction on the same account, with the same amount, and with a date +/-10 days from the imported transaction date.
Transactions imported through File Based Import or Direct Import (not through the API) are assigned an import_id in the format: ‘YNAB::[iso_date]:’. For example, a transaction dated 2015-12-30 in the amount of -$294.23 USD would have an import_id of ‘YNAB:-294230:2015-12-30:1’. If a second transaction on the same account was imported and had the same date and same amount, its import_id would be ‘YNAB:-294230:2015-12-30:2’. Using a consistent format will prevent duplicates through Direct Import and File Based Import.
If import_id is omitted or specified as null, the transaction will be treated as a "user-entered" transaction. As such, it will be eligible to be matched against transactions later being imported (via DI, FBI, or API).



45
46
47
# File 'lib/ynab/models/new_transaction.rb', line 45

def import_id
  @import_id
end

#memoObject

Returns the value of attribute memo.



32
33
34
# File 'lib/ynab/models/new_transaction.rb', line 32

def memo
  @memo
end

#payee_idObject

The payee for the transaction. To create a transfer between two accounts, use the account transfer payee pointing to the target account. Account transfer payees are specified as transfer_payee_id on the account resource.



24
25
26
# File 'lib/ynab/models/new_transaction.rb', line 24

def payee_id
  @payee_id
end

#payee_nameObject

The payee name. If a payee_name value is provided and payee_id has a null value, the payee_name value will be used to resolve the payee by either (1) a matching payee rename rule (only if import_id is also specified) or (2) a payee with the same name or (3) creation of a new payee.



27
28
29
# File 'lib/ynab/models/new_transaction.rb', line 27

def payee_name
  @payee_name
end

#subtransactionsObject

An array of subtransactions to configure a transaction as a split. Updating subtransactions on an existing split transaction is not supported.



42
43
44
# File 'lib/ynab/models/new_transaction.rb', line 42

def subtransactions
  @subtransactions
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/ynab/models/new_transaction.rb', line 88

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/ynab/models/new_transaction.rb', line 70

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'date' => :'date',
    :'amount' => :'amount',
    :'payee_id' => :'payee_id',
    :'payee_name' => :'payee_name',
    :'category_id' => :'category_id',
    :'memo' => :'memo',
    :'cleared' => :'cleared',
    :'approved' => :'approved',
    :'flag_color' => :'flag_color',
    :'subtransactions' => :'subtransactions',
    :'import_id' => :'import_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/ynab/models/new_transaction.rb', line 259

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



119
120
121
122
123
# File 'lib/ynab/models/new_transaction.rb', line 119

def self.openapi_all_of
  [
  :'SaveTransactionWithOptionalFields'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
116
# File 'lib/ynab/models/new_transaction.rb', line 111

def self.openapi_nullable
  Set.new([
    :'flag_color',
    :'import_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/ynab/models/new_transaction.rb', line 93

def self.openapi_types
  {
    :'account_id' => :'String',
    :'date' => :'Date',
    :'amount' => :'Integer',
    :'payee_id' => :'String',
    :'payee_name' => :'String',
    :'category_id' => :'String',
    :'memo' => :'String',
    :'cleared' => :'TransactionClearedStatus',
    :'approved' => :'Boolean',
    :'flag_color' => :'TransactionFlagColor',
    :'subtransactions' => :'Array<SaveSubTransaction>',
    :'import_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/ynab/models/new_transaction.rb', line 227

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      date == o.date &&
      amount == o.amount &&
      payee_id == o.payee_id &&
      payee_name == o.payee_name &&
      category_id == o.category_id &&
      memo == o.memo &&
      cleared == o.cleared &&
      approved == o.approved &&
      flag_color == o.flag_color &&
      subtransactions == o.subtransactions &&
      import_id == o.import_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/ynab/models/new_transaction.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/ynab/models/new_transaction.rb', line 252

def hash
  [, date, amount, payee_id, payee_name, category_id, memo, cleared, approved, flag_color, subtransactions, import_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



193
194
195
196
# File 'lib/ynab/models/new_transaction.rb', line 193

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/ynab/models/new_transaction.rb', line 281

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
203
204
205
# File 'lib/ynab/models/new_transaction.rb', line 200

def valid?
  return false if !@payee_name.nil? && @payee_name.to_s.length > 200
  return false if !@memo.nil? && @memo.to_s.length > 500
  return false if !@import_id.nil? && @import_id.to_s.length > 36
  true
end