Class: YNAB::Payee

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/payee.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Payee

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/ynab/models/payee.rb', line 59

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::Payee` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::Payee`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'transfer_account_id')
    self. = attributes[:'transfer_account_id']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end
end

Instance Attribute Details

#deletedObject

Whether or not the payee has been deleted. Deleted payees will only be included in delta requests.



23
24
25
# File 'lib/ynab/models/payee.rb', line 23

def deleted
  @deleted
end

#idObject

Returns the value of attribute id.



15
16
17
# File 'lib/ynab/models/payee.rb', line 15

def id
  @id
end

#nameObject

Returns the value of attribute name.



17
18
19
# File 'lib/ynab/models/payee.rb', line 17

def name
  @name
end

#transfer_account_idObject

If a transfer payee, the account_id to which this payee transfers to



20
21
22
# File 'lib/ynab/models/payee.rb', line 20

def 
  @transfer_account_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



36
37
38
# File 'lib/ynab/models/payee.rb', line 36

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
# File 'lib/ynab/models/payee.rb', line 26

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'transfer_account_id' => :'transfer_account_id',
    :'deleted' => :'deleted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/ynab/models/payee.rb', line 131

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



51
52
53
54
55
# File 'lib/ynab/models/payee.rb', line 51

def self.openapi_nullable
  Set.new([
    :'transfer_account_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



41
42
43
44
45
46
47
48
# File 'lib/ynab/models/payee.rb', line 41

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'transfer_account_id' => :'String',
    :'deleted' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



107
108
109
110
111
112
113
114
# File 'lib/ynab/models/payee.rb', line 107

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
       == o. &&
      deleted == o.deleted
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


118
119
120
# File 'lib/ynab/models/payee.rb', line 118

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



124
125
126
# File 'lib/ynab/models/payee.rb', line 124

def hash
  [id, name, , deleted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



91
92
93
94
# File 'lib/ynab/models/payee.rb', line 91

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/ynab/models/payee.rb', line 153

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



98
99
100
101
102
103
# File 'lib/ynab/models/payee.rb', line 98

def valid?
  return false if @id.nil?
  return false if @name.nil?
  return false if @deleted.nil?
  true
end