Class: YNAB::PayeeLocation

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/payee_location.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PayeeLocation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/ynab/models/payee_location.rb', line 61

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::PayeeLocation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::PayeeLocation`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'payee_id')
    self.payee_id = attributes[:'payee_id']
  end

  if attributes.key?(:'latitude')
    self.latitude = attributes[:'latitude']
  end

  if attributes.key?(:'longitude')
    self.longitude = attributes[:'longitude']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end
end

Instance Attribute Details

#deletedObject

Whether or not the payee location has been deleted. Deleted payee locations will only be included in delta requests.



24
25
26
# File 'lib/ynab/models/payee_location.rb', line 24

def deleted
  @deleted
end

#idObject

Returns the value of attribute id.



15
16
17
# File 'lib/ynab/models/payee_location.rb', line 15

def id
  @id
end

#latitudeObject

Returns the value of attribute latitude.



19
20
21
# File 'lib/ynab/models/payee_location.rb', line 19

def latitude
  @latitude
end

#longitudeObject

Returns the value of attribute longitude.



21
22
23
# File 'lib/ynab/models/payee_location.rb', line 21

def longitude
  @longitude
end

#payee_idObject

Returns the value of attribute payee_id.



17
18
19
# File 'lib/ynab/models/payee_location.rb', line 17

def payee_id
  @payee_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/ynab/models/payee_location.rb', line 38

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
# File 'lib/ynab/models/payee_location.rb', line 27

def self.attribute_map
  {
    :'id' => :'id',
    :'payee_id' => :'payee_id',
    :'latitude' => :'latitude',
    :'longitude' => :'longitude',
    :'deleted' => :'deleted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/ynab/models/payee_location.rb', line 140

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



54
55
56
57
# File 'lib/ynab/models/payee_location.rb', line 54

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
51
# File 'lib/ynab/models/payee_location.rb', line 43

def self.openapi_types
  {
    :'id' => :'String',
    :'payee_id' => :'String',
    :'latitude' => :'String',
    :'longitude' => :'String',
    :'deleted' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



115
116
117
118
119
120
121
122
123
# File 'lib/ynab/models/payee_location.rb', line 115

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      payee_id == o.payee_id &&
      latitude == o.latitude &&
      longitude == o.longitude &&
      deleted == o.deleted
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


127
128
129
# File 'lib/ynab/models/payee_location.rb', line 127

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



133
134
135
# File 'lib/ynab/models/payee_location.rb', line 133

def hash
  [id, payee_id, latitude, longitude, deleted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



97
98
99
100
# File 'lib/ynab/models/payee_location.rb', line 97

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/ynab/models/payee_location.rb', line 162

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



104
105
106
107
108
109
110
111
# File 'lib/ynab/models/payee_location.rb', line 104

def valid?
  return false if @id.nil?
  return false if @payee_id.nil?
  return false if @latitude.nil?
  return false if @longitude.nil?
  return false if @deleted.nil?
  true
end