Class: YNAB::PayeeLocationsApi
- Inherits:
-
Object
- Object
- YNAB::PayeeLocationsApi
- Defined in:
- lib/ynab/api/payee_locations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_payee_location_by_id(plan_id, payee_location_id, opts = {}) ⇒ PayeeLocationResponse
Get a payee location Returns a single payee location.
-
#get_payee_location_by_id_with_http_info(plan_id, payee_location_id, opts = {}) ⇒ Array<(PayeeLocationResponse, Integer, Hash)>
Get a payee location Returns a single payee location.
-
#get_payee_locations(plan_id, opts = {}) ⇒ PayeeLocationsResponse
Get all payee locations Returns all payee locations.
-
#get_payee_locations_by_payee(plan_id, payee_id, opts = {}) ⇒ PayeeLocationsResponse
Get all locations for a payee Returns all payee locations for a specified payee.
-
#get_payee_locations_by_payee_with_http_info(plan_id, payee_id, opts = {}) ⇒ Array<(PayeeLocationsResponse, Integer, Hash)>
Get all locations for a payee Returns all payee locations for a specified payee.
-
#get_payee_locations_with_http_info(plan_id, opts = {}) ⇒ Array<(PayeeLocationsResponse, Integer, Hash)>
Get all payee locations Returns all payee locations.
-
#initialize(api_client = ApiClient.default) ⇒ PayeeLocationsApi
constructor
A new instance of PayeeLocationsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PayeeLocationsApi
Returns a new instance of PayeeLocationsApi.
15 16 17 |
# File 'lib/ynab/api/payee_locations_api.rb', line 15 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/ynab/api/payee_locations_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#get_payee_location_by_id(plan_id, payee_location_id, opts = {}) ⇒ PayeeLocationResponse
Get a payee location Returns a single payee location
24 25 26 27 |
# File 'lib/ynab/api/payee_locations_api.rb', line 24 def get_payee_location_by_id(plan_id, payee_location_id, opts = {}) data, _status_code, _headers = get_payee_location_by_id_with_http_info(plan_id, payee_location_id, opts) data end |
#get_payee_location_by_id_with_http_info(plan_id, payee_location_id, opts = {}) ⇒ Array<(PayeeLocationResponse, Integer, Hash)>
Get a payee location Returns a single payee location
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/ynab/api/payee_locations_api.rb', line 35 def get_payee_location_by_id_with_http_info(plan_id, payee_location_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PayeeLocationsApi.get_payee_location_by_id ...' end # verify the required parameter 'plan_id' is set if @api_client.config.client_side_validation && plan_id.nil? fail ArgumentError, "Missing the required parameter 'plan_id' when calling PayeeLocationsApi.get_payee_location_by_id" end # verify the required parameter 'payee_location_id' is set if @api_client.config.client_side_validation && payee_location_id.nil? fail ArgumentError, "Missing the required parameter 'payee_location_id' when calling PayeeLocationsApi.get_payee_location_by_id" end # resource path local_var_path = '/plans/{plan_id}/payee_locations/{payee_location_id}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'payee_location_id' + '}', CGI.escape(payee_location_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PayeeLocationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer'] = opts.merge( :operation => :"PayeeLocationsApi.get_payee_location_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PayeeLocationsApi#get_payee_location_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_payee_locations(plan_id, opts = {}) ⇒ PayeeLocationsResponse
Get all payee locations Returns all payee locations
92 93 94 95 |
# File 'lib/ynab/api/payee_locations_api.rb', line 92 def get_payee_locations(plan_id, opts = {}) data, _status_code, _headers = get_payee_locations_with_http_info(plan_id, opts) data end |
#get_payee_locations_by_payee(plan_id, payee_id, opts = {}) ⇒ PayeeLocationsResponse
Get all locations for a payee Returns all payee locations for a specified payee
156 157 158 159 |
# File 'lib/ynab/api/payee_locations_api.rb', line 156 def get_payee_locations_by_payee(plan_id, payee_id, opts = {}) data, _status_code, _headers = get_payee_locations_by_payee_with_http_info(plan_id, payee_id, opts) data end |
#get_payee_locations_by_payee_with_http_info(plan_id, payee_id, opts = {}) ⇒ Array<(PayeeLocationsResponse, Integer, Hash)>
Get all locations for a payee Returns all payee locations for a specified payee
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/ynab/api/payee_locations_api.rb', line 167 def get_payee_locations_by_payee_with_http_info(plan_id, payee_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PayeeLocationsApi.get_payee_locations_by_payee ...' end # verify the required parameter 'plan_id' is set if @api_client.config.client_side_validation && plan_id.nil? fail ArgumentError, "Missing the required parameter 'plan_id' when calling PayeeLocationsApi.get_payee_locations_by_payee" end # verify the required parameter 'payee_id' is set if @api_client.config.client_side_validation && payee_id.nil? fail ArgumentError, "Missing the required parameter 'payee_id' when calling PayeeLocationsApi.get_payee_locations_by_payee" end # resource path local_var_path = '/plans/{plan_id}/payees/{payee_id}/payee_locations'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'payee_id' + '}', CGI.escape(payee_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PayeeLocationsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer'] = opts.merge( :operation => :"PayeeLocationsApi.get_payee_locations_by_payee", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PayeeLocationsApi#get_payee_locations_by_payee\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_payee_locations_with_http_info(plan_id, opts = {}) ⇒ Array<(PayeeLocationsResponse, Integer, Hash)>
Get all payee locations Returns all payee locations
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/ynab/api/payee_locations_api.rb', line 102 def get_payee_locations_with_http_info(plan_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PayeeLocationsApi.get_payee_locations ...' end # verify the required parameter 'plan_id' is set if @api_client.config.client_side_validation && plan_id.nil? fail ArgumentError, "Missing the required parameter 'plan_id' when calling PayeeLocationsApi.get_payee_locations" end # resource path local_var_path = '/plans/{plan_id}/payee_locations'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PayeeLocationsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer'] = opts.merge( :operation => :"PayeeLocationsApi.get_payee_locations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PayeeLocationsApi#get_payee_locations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |