Class: YNAB::PayeesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ynab/api/payees_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PayeesApi

Returns a new instance of PayeesApi.



15
16
17
# File 'lib/ynab/api/payees_api.rb', line 15

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



13
14
15
# File 'lib/ynab/api/payees_api.rb', line 13

def api_client
  @api_client
end

Instance Method Details

#get_payee_by_id(plan_id, payee_id, opts = {}) ⇒ PayeeResponse

Get a payee Returns a single payee

Parameters:

  • plan_id (String)

    The id of the plan. "last-used" can be used to specify the last used plan and "default" can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • payee_id (String)

    The id of the payee

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



24
25
26
27
# File 'lib/ynab/api/payees_api.rb', line 24

def get_payee_by_id(plan_id, payee_id, opts = {})
  data, _status_code, _headers = get_payee_by_id_with_http_info(plan_id, payee_id, opts)
  data
end

#get_payee_by_id_with_http_info(plan_id, payee_id, opts = {}) ⇒ Array<(PayeeResponse, Integer, Hash)>

Get a payee Returns a single payee

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • payee_id (String)

    The id of the payee

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PayeeResponse, Integer, Hash)>)

    PayeeResponse data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/ynab/api/payees_api.rb', line 35

def get_payee_by_id_with_http_info(plan_id, payee_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayeesApi.get_payee_by_id ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling PayeesApi.get_payee_by_id"
  end
  # verify the required parameter 'payee_id' is set
  if @api_client.config.client_side_validation && payee_id.nil?
    fail ArgumentError, "Missing the required parameter 'payee_id' when calling PayeesApi.get_payee_by_id"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/payees/{payee_id}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'payee_id' + '}', CGI.escape(payee_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PayeeResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"PayeesApi.get_payee_by_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayeesApi#get_payee_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_payees(plan_id, opts = {}) ⇒ PayeesResponse

Get all payees Returns all payees

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :last_knowledge_of_server (Integer)

    The starting server knowledge. If provided, only entities that have changed since &#x60;last_knowledge_of_server&#x60; will be included.

Returns:



93
94
95
96
# File 'lib/ynab/api/payees_api.rb', line 93

def get_payees(plan_id, opts = {})
  data, _status_code, _headers = get_payees_with_http_info(plan_id, opts)
  data
end

#get_payees_with_http_info(plan_id, opts = {}) ⇒ Array<(PayeesResponse, Integer, Hash)>

Get all payees Returns all payees

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :last_knowledge_of_server (Integer)

    The starting server knowledge. If provided, only entities that have changed since &#x60;last_knowledge_of_server&#x60; will be included.

Returns:

  • (Array<(PayeesResponse, Integer, Hash)>)

    PayeesResponse data, response status code and response headers



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/ynab/api/payees_api.rb', line 104

def get_payees_with_http_info(plan_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayeesApi.get_payees ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling PayeesApi.get_payees"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/payees'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'last_knowledge_of_server'] = opts[:'last_knowledge_of_server'] if !opts[:'last_knowledge_of_server'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PayeesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"PayeesApi.get_payees",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayeesApi#get_payees\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_payee(plan_id, payee_id, data, opts = {}) ⇒ SavePayeeResponse

Update a payee Update a payee

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • payee_id (String)

    The id of the payee

  • data (PatchPayeeWrapper)

    The payee to update

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



160
161
162
163
# File 'lib/ynab/api/payees_api.rb', line 160

def update_payee(plan_id, payee_id, data, opts = {})
  data, _status_code, _headers = update_payee_with_http_info(plan_id, payee_id, data, opts)
  data
end

#update_payee_with_http_info(plan_id, payee_id, data, opts = {}) ⇒ Array<(SavePayeeResponse, Integer, Hash)>

Update a payee Update a payee

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • payee_id (String)

    The id of the payee

  • data (PatchPayeeWrapper)

    The payee to update

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(SavePayeeResponse, Integer, Hash)>)

    SavePayeeResponse data, response status code and response headers



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/ynab/api/payees_api.rb', line 172

def update_payee_with_http_info(plan_id, payee_id, data, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayeesApi.update_payee ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling PayeesApi.update_payee"
  end
  # verify the required parameter 'payee_id' is set
  if @api_client.config.client_side_validation && payee_id.nil?
    fail ArgumentError, "Missing the required parameter 'payee_id' when calling PayeesApi.update_payee"
  end
  # verify the required parameter 'data' is set
  if @api_client.config.client_side_validation && data.nil?
    fail ArgumentError, "Missing the required parameter 'data' when calling PayeesApi.update_payee"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/payees/{payee_id}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'payee_id' + '}', CGI.escape(payee_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(data)

  # return_type
  return_type = opts[:debug_return_type] || 'SavePayeeResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"PayeesApi.update_payee",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayeesApi#update_payee\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end