Class: YNAB::PlanDetail

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/plan_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PlanDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/ynab/models/plan_detail.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::PlanDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::PlanDetail`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'last_modified_on')
    self.last_modified_on = attributes[:'last_modified_on']
  end

  if attributes.key?(:'first_month')
    self.first_month = attributes[:'first_month']
  end

  if attributes.key?(:'last_month')
    self.last_month = attributes[:'last_month']
  end

  if attributes.key?(:'date_format')
    self.date_format = attributes[:'date_format']
  end

  if attributes.key?(:'currency_format')
    self.currency_format = attributes[:'currency_format']
  end

  if attributes.key?(:'accounts')
    if (value = attributes[:'accounts']).is_a?(Array)
      self.accounts = value
    end
  end

  if attributes.key?(:'payees')
    if (value = attributes[:'payees']).is_a?(Array)
      self.payees = value
    end
  end

  if attributes.key?(:'payee_locations')
    if (value = attributes[:'payee_locations']).is_a?(Array)
      self.payee_locations = value
    end
  end

  if attributes.key?(:'category_groups')
    if (value = attributes[:'category_groups']).is_a?(Array)
      self.category_groups = value
    end
  end

  if attributes.key?(:'categories')
    if (value = attributes[:'categories']).is_a?(Array)
      self.categories = value
    end
  end

  if attributes.key?(:'months')
    if (value = attributes[:'months']).is_a?(Array)
      self.months = value
    end
  end

  if attributes.key?(:'transactions')
    if (value = attributes[:'transactions']).is_a?(Array)
      self.transactions = value
    end
  end

  if attributes.key?(:'subtransactions')
    if (value = attributes[:'subtransactions']).is_a?(Array)
      self.subtransactions = value
    end
  end

  if attributes.key?(:'scheduled_transactions')
    if (value = attributes[:'scheduled_transactions']).is_a?(Array)
      self.scheduled_transactions = value
    end
  end

  if attributes.key?(:'scheduled_subtransactions')
    if (value = attributes[:'scheduled_subtransactions']).is_a?(Array)
      self.scheduled_subtransactions = value
    end
  end
end

Instance Attribute Details

#accountsObject

Returns the value of attribute accounts.



32
33
34
# File 'lib/ynab/models/plan_detail.rb', line 32

def accounts
  @accounts
end

#categoriesObject

Returns the value of attribute categories.



40
41
42
# File 'lib/ynab/models/plan_detail.rb', line 40

def categories
  @categories
end

#category_groupsObject

Returns the value of attribute category_groups.



38
39
40
# File 'lib/ynab/models/plan_detail.rb', line 38

def category_groups
  @category_groups
end

#currency_formatObject

Returns the value of attribute currency_format.



30
31
32
# File 'lib/ynab/models/plan_detail.rb', line 30

def currency_format
  @currency_format
end

#date_formatObject

Returns the value of attribute date_format.



28
29
30
# File 'lib/ynab/models/plan_detail.rb', line 28

def date_format
  @date_format
end

#first_monthObject

The earliest plan month



23
24
25
# File 'lib/ynab/models/plan_detail.rb', line 23

def first_month
  @first_month
end

#idObject

Returns the value of attribute id.



15
16
17
# File 'lib/ynab/models/plan_detail.rb', line 15

def id
  @id
end

#last_modified_onObject

The last time any changes were made to the plan from either a web or mobile client



20
21
22
# File 'lib/ynab/models/plan_detail.rb', line 20

def last_modified_on
  @last_modified_on
end

#last_monthObject

The latest plan month



26
27
28
# File 'lib/ynab/models/plan_detail.rb', line 26

def last_month
  @last_month
end

#monthsObject

Returns the value of attribute months.



42
43
44
# File 'lib/ynab/models/plan_detail.rb', line 42

def months
  @months
end

#nameObject

Returns the value of attribute name.



17
18
19
# File 'lib/ynab/models/plan_detail.rb', line 17

def name
  @name
end

#payee_locationsObject

Returns the value of attribute payee_locations.



36
37
38
# File 'lib/ynab/models/plan_detail.rb', line 36

def payee_locations
  @payee_locations
end

#payeesObject

Returns the value of attribute payees.



34
35
36
# File 'lib/ynab/models/plan_detail.rb', line 34

def payees
  @payees
end

#scheduled_subtransactionsObject

Returns the value of attribute scheduled_subtransactions.



50
51
52
# File 'lib/ynab/models/plan_detail.rb', line 50

def scheduled_subtransactions
  @scheduled_subtransactions
end

#scheduled_transactionsObject

Returns the value of attribute scheduled_transactions.



48
49
50
# File 'lib/ynab/models/plan_detail.rb', line 48

def scheduled_transactions
  @scheduled_transactions
end

#subtransactionsObject

Returns the value of attribute subtransactions.



46
47
48
# File 'lib/ynab/models/plan_detail.rb', line 46

def subtransactions
  @subtransactions
end

#transactionsObject

Returns the value of attribute transactions.



44
45
46
# File 'lib/ynab/models/plan_detail.rb', line 44

def transactions
  @transactions
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/ynab/models/plan_detail.rb', line 76

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/ynab/models/plan_detail.rb', line 53

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'last_modified_on' => :'last_modified_on',
    :'first_month' => :'first_month',
    :'last_month' => :'last_month',
    :'date_format' => :'date_format',
    :'currency_format' => :'currency_format',
    :'accounts' => :'accounts',
    :'payees' => :'payees',
    :'payee_locations' => :'payee_locations',
    :'category_groups' => :'category_groups',
    :'categories' => :'categories',
    :'months' => :'months',
    :'transactions' => :'transactions',
    :'subtransactions' => :'subtransactions',
    :'scheduled_transactions' => :'scheduled_transactions',
    :'scheduled_subtransactions' => :'scheduled_subtransactions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/ynab/models/plan_detail.rb', line 274

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



110
111
112
113
114
# File 'lib/ynab/models/plan_detail.rb', line 110

def self.openapi_all_of
  [
  :'PlanSummary'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/ynab/models/plan_detail.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/ynab/models/plan_detail.rb', line 81

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'last_modified_on' => :'Time',
    :'first_month' => :'Date',
    :'last_month' => :'Date',
    :'date_format' => :'DateFormat',
    :'currency_format' => :'CurrencyFormat',
    :'accounts' => :'Array<Account>',
    :'payees' => :'Array<Payee>',
    :'payee_locations' => :'Array<PayeeLocation>',
    :'category_groups' => :'Array<CategoryGroup>',
    :'categories' => :'Array<Category>',
    :'months' => :'Array<MonthDetail>',
    :'transactions' => :'Array<TransactionSummary>',
    :'subtransactions' => :'Array<SubTransaction>',
    :'scheduled_transactions' => :'Array<ScheduledTransactionSummary>',
    :'scheduled_subtransactions' => :'Array<ScheduledSubTransaction>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/ynab/models/plan_detail.rb', line 237

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      last_modified_on == o.last_modified_on &&
      first_month == o.first_month &&
      last_month == o.last_month &&
      date_format == o.date_format &&
      currency_format == o.currency_format &&
      accounts == o.accounts &&
      payees == o.payees &&
      payee_locations == o.payee_locations &&
      category_groups == o.category_groups &&
      categories == o.categories &&
      months == o.months &&
      transactions == o.transactions &&
      subtransactions == o.subtransactions &&
      scheduled_transactions == o.scheduled_transactions &&
      scheduled_subtransactions == o.scheduled_subtransactions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/ynab/models/plan_detail.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



267
268
269
# File 'lib/ynab/models/plan_detail.rb', line 267

def hash
  [id, name, last_modified_on, first_month, last_month, date_format, currency_format, accounts, payees, payee_locations, category_groups, categories, months, transactions, subtransactions, scheduled_transactions, scheduled_subtransactions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



222
223
224
225
# File 'lib/ynab/models/plan_detail.rb', line 222

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/ynab/models/plan_detail.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



229
230
231
232
233
# File 'lib/ynab/models/plan_detail.rb', line 229

def valid?
  return false if @id.nil?
  return false if @name.nil?
  true
end