Class: YNAB::PlanSettings
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::PlanSettings
- Defined in:
- lib/ynab/models/plan_settings.rb
Instance Attribute Summary collapse
-
#currency_format ⇒ Object
Returns the value of attribute currency_format.
-
#date_format ⇒ Object
Returns the value of attribute date_format.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PlanSettings
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PlanSettings
Initializes the object
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/ynab/models/plan_settings.rb', line 48 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::PlanSettings` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::PlanSettings`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date_format') self.date_format = attributes[:'date_format'] end if attributes.key?(:'currency_format') self.currency_format = attributes[:'currency_format'] end end |
Instance Attribute Details
#currency_format ⇒ Object
Returns the value of attribute currency_format.
17 18 19 |
# File 'lib/ynab/models/plan_settings.rb', line 17 def currency_format @currency_format end |
#date_format ⇒ Object
Returns the value of attribute date_format.
15 16 17 |
# File 'lib/ynab/models/plan_settings.rb', line 15 def date_format @date_format end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
28 29 30 |
# File 'lib/ynab/models/plan_settings.rb', line 28 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 |
# File 'lib/ynab/models/plan_settings.rb', line 20 def self.attribute_map { :'date_format' => :'date_format', :'currency_format' => :'currency_format' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/ynab/models/plan_settings.rb', line 109 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
41 42 43 44 |
# File 'lib/ynab/models/plan_settings.rb', line 41 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 |
# File 'lib/ynab/models/plan_settings.rb', line 33 def self.openapi_types { :'date_format' => :'DateFormat', :'currency_format' => :'CurrencyFormat' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
87 88 89 90 91 92 |
# File 'lib/ynab/models/plan_settings.rb', line 87 def ==(o) return true if self.equal?(o) self.class == o.class && date_format == o.date_format && currency_format == o.currency_format end |
#eql?(o) ⇒ Boolean
96 97 98 |
# File 'lib/ynab/models/plan_settings.rb', line 96 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
102 103 104 |
# File 'lib/ynab/models/plan_settings.rb', line 102 def hash [date_format, currency_format].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
72 73 74 75 |
# File 'lib/ynab/models/plan_settings.rb', line 72 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/ynab/models/plan_settings.rb', line 131 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
79 80 81 82 83 |
# File 'lib/ynab/models/plan_settings.rb', line 79 def valid? return false if @date_format.nil? return false if @currency_format.nil? true end |