Class: YNAB::PlansApi
- Inherits:
-
Object
- Object
- YNAB::PlansApi
- Defined in:
- lib/ynab/api/plans_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_plan_by_id(plan_id, opts = {}) ⇒ PlanDetailResponse
Get a plan Returns a single plan with all related entities.
-
#get_plan_by_id_with_http_info(plan_id, opts = {}) ⇒ Array<(PlanDetailResponse, Integer, Hash)>
Get a plan Returns a single plan with all related entities.
-
#get_plan_settings_by_id(plan_id, opts = {}) ⇒ PlanSettingsResponse
Get plan settings Returns settings for a plan.
-
#get_plan_settings_by_id_with_http_info(plan_id, opts = {}) ⇒ Array<(PlanSettingsResponse, Integer, Hash)>
Get plan settings Returns settings for a plan.
-
#get_plans(opts = {}) ⇒ PlanSummaryResponse
Get all plans Returns plans list with summary information.
-
#get_plans_with_http_info(opts = {}) ⇒ Array<(PlanSummaryResponse, Integer, Hash)>
Get all plans Returns plans list with summary information.
-
#initialize(api_client = ApiClient.default) ⇒ PlansApi
constructor
A new instance of PlansApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/ynab/api/plans_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#get_plan_by_id(plan_id, opts = {}) ⇒ PlanDetailResponse
Get a plan Returns a single plan with all related entities. This resource is effectively a full plan export.
24 25 26 27 |
# File 'lib/ynab/api/plans_api.rb', line 24 def get_plan_by_id(plan_id, opts = {}) data, _status_code, _headers = get_plan_by_id_with_http_info(plan_id, opts) data end |
#get_plan_by_id_with_http_info(plan_id, opts = {}) ⇒ Array<(PlanDetailResponse, Integer, Hash)>
Get a plan Returns a single plan with all related entities. This resource is effectively a full plan export.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/ynab/api/plans_api.rb', line 35 def get_plan_by_id_with_http_info(plan_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlansApi.get_plan_by_id ...' end # verify the required parameter 'plan_id' is set if @api_client.config.client_side_validation && plan_id.nil? fail ArgumentError, "Missing the required parameter 'plan_id' when calling PlansApi.get_plan_by_id" end # resource path local_var_path = '/plans/{plan_id}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'last_knowledge_of_server'] = opts[:'last_knowledge_of_server'] if !opts[:'last_knowledge_of_server'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PlanDetailResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer'] = opts.merge( :operation => :"PlansApi.get_plan_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlansApi#get_plan_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_plan_settings_by_id(plan_id, opts = {}) ⇒ PlanSettingsResponse
Get plan settings Returns settings for a plan
89 90 91 92 |
# File 'lib/ynab/api/plans_api.rb', line 89 def get_plan_settings_by_id(plan_id, opts = {}) data, _status_code, _headers = get_plan_settings_by_id_with_http_info(plan_id, opts) data end |
#get_plan_settings_by_id_with_http_info(plan_id, opts = {}) ⇒ Array<(PlanSettingsResponse, Integer, Hash)>
Get plan settings Returns settings for a plan
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/ynab/api/plans_api.rb', line 99 def get_plan_settings_by_id_with_http_info(plan_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlansApi.get_plan_settings_by_id ...' end # verify the required parameter 'plan_id' is set if @api_client.config.client_side_validation && plan_id.nil? fail ArgumentError, "Missing the required parameter 'plan_id' when calling PlansApi.get_plan_settings_by_id" end # resource path local_var_path = '/plans/{plan_id}/settings'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PlanSettingsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer'] = opts.merge( :operation => :"PlansApi.get_plan_settings_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlansApi#get_plan_settings_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_plans(opts = {}) ⇒ PlanSummaryResponse
Get all plans Returns plans list with summary information
152 153 154 155 |
# File 'lib/ynab/api/plans_api.rb', line 152 def get_plans(opts = {}) data, _status_code, _headers = get_plans_with_http_info(opts) data end |
#get_plans_with_http_info(opts = {}) ⇒ Array<(PlanSummaryResponse, Integer, Hash)>
Get all plans Returns plans list with summary information
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/ynab/api/plans_api.rb', line 162 def get_plans_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlansApi.get_plans ...' end # resource path local_var_path = '/plans' # query parameters query_params = opts[:query_params] || {} query_params[:'include_accounts'] = opts[:'include_accounts'] if !opts[:'include_accounts'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PlanSummaryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer'] = opts.merge( :operation => :"PlansApi.get_plans", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlansApi#get_plans\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |