Class: YNAB::SaveAccount
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::SaveAccount
- Defined in:
- lib/ynab/models/save_account.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#balance ⇒ Object
The current balance of the account in milliunits format.
-
#name ⇒ Object
The name of the account.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SaveAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SaveAccount
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/ynab/models/save_account.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::SaveAccount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::SaveAccount`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'balance') self.balance = attributes[:'balance'] end end |
Instance Attribute Details
#balance ⇒ Object
The current balance of the account in milliunits format
21 22 23 |
# File 'lib/ynab/models/save_account.rb', line 21 def balance @balance end |
#name ⇒ Object
The name of the account
16 17 18 |
# File 'lib/ynab/models/save_account.rb', line 16 def name @name end |
#type ⇒ Object
Returns the value of attribute type.
18 19 20 |
# File 'lib/ynab/models/save_account.rb', line 18 def type @type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/ynab/models/save_account.rb', line 55 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 |
# File 'lib/ynab/models/save_account.rb', line 46 def self.attribute_map { :'name' => :'name', :'type' => :'type', :'balance' => :'balance' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/ynab/models/save_account.rb', line 143 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/ynab/models/save_account.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 |
# File 'lib/ynab/models/save_account.rb', line 60 def self.openapi_types { :'name' => :'String', :'type' => :'AccountType', :'balance' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 |
# File 'lib/ynab/models/save_account.rb', line 120 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && type == o.type && balance == o.balance end |
#eql?(o) ⇒ Boolean
130 131 132 |
# File 'lib/ynab/models/save_account.rb', line 130 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/ynab/models/save_account.rb', line 136 def hash [name, type, balance].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
104 105 106 107 |
# File 'lib/ynab/models/save_account.rb', line 104 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/ynab/models/save_account.rb', line 165 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
111 112 113 114 115 116 |
# File 'lib/ynab/models/save_account.rb', line 111 def valid? return false if @name.nil? return false if @type.nil? return false if @balance.nil? true end |