Class: YNAB::SavePayee
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::SavePayee
- Defined in:
- lib/ynab/models/save_payee.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the payee.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SavePayee
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SavePayee
Initializes the object
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/ynab/models/save_payee.rb', line 45 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::SavePayee` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::SavePayee`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end end |
Instance Attribute Details
#name ⇒ Object
The name of the payee. The name must be a maximum of 500 characters.
16 17 18 |
# File 'lib/ynab/models/save_payee.rb', line 16 def name @name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
26 27 28 |
# File 'lib/ynab/models/save_payee.rb', line 26 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
19 20 21 22 23 |
# File 'lib/ynab/models/save_payee.rb', line 19 def self.attribute_map { :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/ynab/models/save_payee.rb', line 106 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
38 39 40 41 |
# File 'lib/ynab/models/save_payee.rb', line 38 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
31 32 33 34 35 |
# File 'lib/ynab/models/save_payee.rb', line 31 def self.openapi_types { :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 |
# File 'lib/ynab/models/save_payee.rb', line 85 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name end |
#eql?(o) ⇒ Boolean
93 94 95 |
# File 'lib/ynab/models/save_payee.rb', line 93 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
99 100 101 |
# File 'lib/ynab/models/save_payee.rb', line 99 def hash [name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
65 66 67 68 |
# File 'lib/ynab/models/save_payee.rb', line 65 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/ynab/models/save_payee.rb', line 128 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
72 73 74 75 |
# File 'lib/ynab/models/save_payee.rb', line 72 def valid? return false if !@name.nil? && @name.to_s.length > 500 true end |