Class: YNAB::SaveTransactionsResponseData

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/save_transactions_response_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SaveTransactionsResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/ynab/models/save_transactions_response_data.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::SaveTransactionsResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::SaveTransactionsResponseData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'transaction_ids')
    if (value = attributes[:'transaction_ids']).is_a?(Array)
      self.transaction_ids = value
    end
  end

  if attributes.key?(:'transaction')
    self.transaction = attributes[:'transaction']
  end

  if attributes.key?(:'transactions')
    if (value = attributes[:'transactions']).is_a?(Array)
      self.transactions = value
    end
  end

  if attributes.key?(:'duplicate_import_ids')
    if (value = attributes[:'duplicate_import_ids']).is_a?(Array)
      self.duplicate_import_ids = value
    end
  end

  if attributes.key?(:'server_knowledge')
    self.server_knowledge = attributes[:'server_knowledge']
  end
end

Instance Attribute Details

#duplicate_import_idsObject

If multiple transactions were specified, a list of import_ids that were not created because of an existing import_id found on the same account



24
25
26
# File 'lib/ynab/models/save_transactions_response_data.rb', line 24

def duplicate_import_ids
  @duplicate_import_ids
end

#server_knowledgeObject

The knowledge of the server



27
28
29
# File 'lib/ynab/models/save_transactions_response_data.rb', line 27

def server_knowledge
  @server_knowledge
end

#transactionObject

Returns the value of attribute transaction.



18
19
20
# File 'lib/ynab/models/save_transactions_response_data.rb', line 18

def transaction
  @transaction
end

#transaction_idsObject

The transaction ids that were saved



16
17
18
# File 'lib/ynab/models/save_transactions_response_data.rb', line 16

def transaction_ids
  @transaction_ids
end

#transactionsObject

If multiple transactions were specified, the transactions that were saved



21
22
23
# File 'lib/ynab/models/save_transactions_response_data.rb', line 21

def transactions
  @transactions
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



41
42
43
# File 'lib/ynab/models/save_transactions_response_data.rb', line 41

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
# File 'lib/ynab/models/save_transactions_response_data.rb', line 30

def self.attribute_map
  {
    :'transaction_ids' => :'transaction_ids',
    :'transaction' => :'transaction',
    :'transactions' => :'transactions',
    :'duplicate_import_ids' => :'duplicate_import_ids',
    :'server_knowledge' => :'server_knowledge'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/ynab/models/save_transactions_response_data.rb', line 146

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/ynab/models/save_transactions_response_data.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
53
54
# File 'lib/ynab/models/save_transactions_response_data.rb', line 46

def self.openapi_types
  {
    :'transaction_ids' => :'Array<String>',
    :'transaction' => :'TransactionDetail',
    :'transactions' => :'Array<TransactionDetail>',
    :'duplicate_import_ids' => :'Array<String>',
    :'server_knowledge' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



121
122
123
124
125
126
127
128
129
# File 'lib/ynab/models/save_transactions_response_data.rb', line 121

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      transaction_ids == o.transaction_ids &&
      transaction == o.transaction &&
      transactions == o.transactions &&
      duplicate_import_ids == o.duplicate_import_ids &&
      server_knowledge == o.server_knowledge
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


133
134
135
# File 'lib/ynab/models/save_transactions_response_data.rb', line 133

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



139
140
141
# File 'lib/ynab/models/save_transactions_response_data.rb', line 139

def hash
  [transaction_ids, transaction, transactions, duplicate_import_ids, server_knowledge].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



106
107
108
109
# File 'lib/ynab/models/save_transactions_response_data.rb', line 106

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/ynab/models/save_transactions_response_data.rb', line 168

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



113
114
115
116
117
# File 'lib/ynab/models/save_transactions_response_data.rb', line 113

def valid?
  return false if @transaction_ids.nil?
  return false if @server_knowledge.nil?
  true
end