Class: YNAB::ScheduledSubTransaction

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/scheduled_sub_transaction.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ScheduledSubTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::ScheduledSubTransaction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::ScheduledSubTransaction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'scheduled_transaction_id')
    self.scheduled_transaction_id = attributes[:'scheduled_transaction_id']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'memo')
    self.memo = attributes[:'memo']
  end

  if attributes.key?(:'payee_id')
    self.payee_id = attributes[:'payee_id']
  end

  if attributes.key?(:'payee_name')
    self.payee_name = attributes[:'payee_name']
  end

  if attributes.key?(:'category_id')
    self.category_id = attributes[:'category_id']
  end

  if attributes.key?(:'category_name')
    self.category_name = attributes[:'category_name']
  end

  if attributes.key?(:'transfer_account_id')
    self. = attributes[:'transfer_account_id']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end
end

Instance Attribute Details

#amountObject

The scheduled subtransaction amount in milliunits format



20
21
22
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 20

def amount
  @amount
end

#category_idObject

Returns the value of attribute category_id.



28
29
30
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 28

def category_id
  @category_id
end

#category_nameObject

Returns the value of attribute category_name.



30
31
32
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 30

def category_name
  @category_name
end

#deletedObject

Whether or not the scheduled subtransaction has been deleted. Deleted scheduled subtransactions will only be included in delta requests.



36
37
38
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 36

def deleted
  @deleted
end

#idObject

Returns the value of attribute id.



15
16
17
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 15

def id
  @id
end

#memoObject

Returns the value of attribute memo.



22
23
24
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 22

def memo
  @memo
end

#payee_idObject

Returns the value of attribute payee_id.



24
25
26
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 24

def payee_id
  @payee_id
end

#payee_nameObject

Returns the value of attribute payee_name.



26
27
28
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 26

def payee_name
  @payee_name
end

#scheduled_transaction_idObject

Returns the value of attribute scheduled_transaction_id.



17
18
19
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 17

def scheduled_transaction_id
  @scheduled_transaction_id
end

#transfer_account_idObject

If a transfer, the account_id which the scheduled subtransaction transfers to



33
34
35
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 33

def 
  
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 55

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 39

def self.attribute_map
  {
    :'id' => :'id',
    :'scheduled_transaction_id' => :'scheduled_transaction_id',
    :'amount' => :'amount',
    :'memo' => :'memo',
    :'payee_id' => :'payee_id',
    :'payee_name' => :'payee_name',
    :'category_id' => :'category_id',
    :'category_name' => :'category_name',
    :'transfer_account_id' => :'transfer_account_id',
    :'deleted' => :'deleted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
82
83
84
85
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 76

def self.openapi_nullable
  Set.new([
    :'memo',
    :'payee_id',
    :'payee_name',
    :'category_id',
    :'category_name',
    :'transfer_account_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 60

def self.openapi_types
  {
    :'id' => :'String',
    :'scheduled_transaction_id' => :'String',
    :'amount' => :'Integer',
    :'memo' => :'String',
    :'payee_id' => :'String',
    :'payee_name' => :'String',
    :'category_id' => :'String',
    :'category_name' => :'String',
    :'transfer_account_id' => :'String',
    :'deleted' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      scheduled_transaction_id == o.scheduled_transaction_id &&
      amount == o.amount &&
      memo == o.memo &&
      payee_id == o.payee_id &&
      payee_name == o.payee_name &&
      category_id == o.category_id &&
      category_name == o.category_name &&
       == o. &&
      deleted == o.deleted
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 185

def hash
  [id, scheduled_transaction_id, amount, memo, payee_id, payee_name, category_id, category_name, , deleted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



145
146
147
148
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 145

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
158
# File 'lib/ynab/models/scheduled_sub_transaction.rb', line 152

def valid?
  return false if @id.nil?
  return false if @scheduled_transaction_id.nil?
  return false if @amount.nil?
  return false if @deleted.nil?
  true
end