Class: YNAB::ScheduledTransactionDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::ScheduledTransactionDetail
- Defined in:
- lib/ynab/models/scheduled_transaction_detail.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_name ⇒ Object
Returns the value of attribute account_name.
-
#amount ⇒ Object
The scheduled transaction amount in milliunits format.
-
#category_id ⇒ Object
Returns the value of attribute category_id.
-
#category_name ⇒ Object
The name of the category.
-
#date_first ⇒ Object
The first date for which the Scheduled Transaction was scheduled.
-
#date_next ⇒ Object
The next date for which the Scheduled Transaction is scheduled.
-
#deleted ⇒ Object
Whether or not the scheduled transaction has been deleted.
-
#flag_color ⇒ Object
Returns the value of attribute flag_color.
-
#flag_name ⇒ Object
The customized name of a transaction flag.
-
#frequency ⇒ Object
Returns the value of attribute frequency.
-
#id ⇒ Object
Returns the value of attribute id.
-
#memo ⇒ Object
Returns the value of attribute memo.
-
#payee_id ⇒ Object
Returns the value of attribute payee_id.
-
#payee_name ⇒ Object
Returns the value of attribute payee_name.
-
#subtransactions ⇒ Object
If a split scheduled transaction, the subtransactions.
-
#transfer_account_id ⇒ Object
If a transfer, the account_id which the scheduled transaction transfers to.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScheduledTransactionDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScheduledTransactionDetail
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::ScheduledTransactionDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::ScheduledTransactionDetail`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'date_first') self.date_first = attributes[:'date_first'] end if attributes.key?(:'date_next') self.date_next = attributes[:'date_next'] end if attributes.key?(:'frequency') self.frequency = attributes[:'frequency'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'memo') self.memo = attributes[:'memo'] end if attributes.key?(:'flag_color') self.flag_color = attributes[:'flag_color'] end if attributes.key?(:'flag_name') self.flag_name = attributes[:'flag_name'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'payee_id') self.payee_id = attributes[:'payee_id'] end if attributes.key?(:'category_id') self.category_id = attributes[:'category_id'] end if attributes.key?(:'transfer_account_id') self.transfer_account_id = attributes[:'transfer_account_id'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'payee_name') self.payee_name = attributes[:'payee_name'] end if attributes.key?(:'category_name') self.category_name = attributes[:'category_name'] end if attributes.key?(:'subtransactions') if (value = attributes[:'subtransactions']).is_a?(Array) self.subtransactions = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
35 36 37 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 35 def account_id @account_id end |
#account_name ⇒ Object
Returns the value of attribute account_name.
47 48 49 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 47 def account_name @account_name end |
#amount ⇒ Object
The scheduled transaction amount in milliunits format
26 27 28 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 26 def amount @amount end |
#category_id ⇒ Object
Returns the value of attribute category_id.
39 40 41 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 39 def category_id @category_id end |
#category_name ⇒ Object
The name of the category. If a split scheduled transaction, this will be ‘Split’.
52 53 54 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 52 def category_name @category_name end |
#date_first ⇒ Object
The first date for which the Scheduled Transaction was scheduled.
18 19 20 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 18 def date_first @date_first end |
#date_next ⇒ Object
The next date for which the Scheduled Transaction is scheduled.
21 22 23 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 21 def date_next @date_next end |
#deleted ⇒ Object
Whether or not the scheduled transaction has been deleted. Deleted scheduled transactions will only be included in delta requests.
45 46 47 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 45 def deleted @deleted end |
#flag_color ⇒ Object
Returns the value of attribute flag_color.
30 31 32 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 30 def flag_color @flag_color end |
#flag_name ⇒ Object
The customized name of a transaction flag
33 34 35 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 33 def flag_name @flag_name end |
#frequency ⇒ Object
Returns the value of attribute frequency.
23 24 25 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 23 def frequency @frequency end |
#id ⇒ Object
Returns the value of attribute id.
15 16 17 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 15 def id @id end |
#memo ⇒ Object
Returns the value of attribute memo.
28 29 30 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 28 def memo @memo end |
#payee_id ⇒ Object
Returns the value of attribute payee_id.
37 38 39 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 37 def payee_id @payee_id end |
#payee_name ⇒ Object
Returns the value of attribute payee_name.
49 50 51 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 49 def payee_name @payee_name end |
#subtransactions ⇒ Object
If a split scheduled transaction, the subtransactions.
55 56 57 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 55 def subtransactions @subtransactions end |
#transfer_account_id ⇒ Object
If a transfer, the account_id which the scheduled transaction transfers to
42 43 44 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 42 def transfer_account_id @transfer_account_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
103 104 105 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 103 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 80 def self.attribute_map { :'id' => :'id', :'date_first' => :'date_first', :'date_next' => :'date_next', :'frequency' => :'frequency', :'amount' => :'amount', :'memo' => :'memo', :'flag_color' => :'flag_color', :'flag_name' => :'flag_name', :'account_id' => :'account_id', :'payee_id' => :'payee_id', :'category_id' => :'category_id', :'transfer_account_id' => :'transfer_account_id', :'deleted' => :'deleted', :'account_name' => :'account_name', :'payee_name' => :'payee_name', :'category_name' => :'category_name', :'subtransactions' => :'subtransactions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 301 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
140 141 142 143 144 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 140 def self.openapi_all_of [ :'ScheduledTransactionSummary' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
131 132 133 134 135 136 137 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 131 def self.openapi_nullable Set.new([ :'flag_color', :'payee_name', :'category_name', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 108 def self.openapi_types { :'id' => :'String', :'date_first' => :'Date', :'date_next' => :'Date', :'frequency' => :'String', :'amount' => :'Integer', :'memo' => :'String', :'flag_color' => :'TransactionFlagColor', :'flag_name' => :'String', :'account_id' => :'String', :'payee_id' => :'String', :'category_id' => :'String', :'transfer_account_id' => :'String', :'deleted' => :'Boolean', :'account_name' => :'String', :'payee_name' => :'String', :'category_name' => :'String', :'subtransactions' => :'Array<ScheduledSubTransaction>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 264 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && date_first == o.date_first && date_next == o.date_next && frequency == o.frequency && amount == o.amount && memo == o.memo && flag_color == o.flag_color && flag_name == o.flag_name && account_id == o.account_id && payee_id == o.payee_id && category_id == o.category_id && transfer_account_id == o.transfer_account_id && deleted == o.deleted && account_name == o.account_name && payee_name == o.payee_name && category_name == o.category_name && subtransactions == o.subtransactions end |
#eql?(o) ⇒ Boolean
288 289 290 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 288 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 294 def hash [id, date_first, date_next, frequency, amount, memo, flag_color, flag_name, account_id, payee_id, category_id, transfer_account_id, deleted, account_name, payee_name, category_name, subtransactions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
234 235 236 237 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 234 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/ynab/models/scheduled_transaction_detail.rb', line 241 def valid? return false if @id.nil? return false if @date_first.nil? return false if @date_next.nil? return false if @frequency.nil? frequency_validator = EnumAttributeValidator.new('String', ["never", "daily", "weekly", "everyOtherWeek", "twiceAMonth", "every4Weeks", "monthly", "everyOtherMonth", "every3Months", "every4Months", "twiceAYear", "yearly", "everyOtherYear"]) return false unless frequency_validator.valid?(@frequency) return false if @amount.nil? return false if @account_id.nil? return false if @deleted.nil? return false if @account_name.nil? return false if @subtransactions.nil? true end |