Class: YNAB::ScheduledTransactionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ynab/api/scheduled_transactions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ScheduledTransactionsApi

Returns a new instance of ScheduledTransactionsApi.



15
16
17
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 15

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



13
14
15
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 13

def api_client
  @api_client
end

Instance Method Details

#create_scheduled_transaction(plan_id, data, opts = {}) ⇒ ScheduledTransactionResponse

Create a scheduled transaction Creates a single scheduled transaction (a transaction with a future date).

Parameters:

  • plan_id (String)

    The id of the plan. "last-used" can be used to specify the last used plan and "default" can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • data (PostScheduledTransactionWrapper)

    The scheduled transaction to create

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



24
25
26
27
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 24

def create_scheduled_transaction(plan_id, data, opts = {})
  data, _status_code, _headers = create_scheduled_transaction_with_http_info(plan_id, data, opts)
  data
end

#create_scheduled_transaction_with_http_info(plan_id, data, opts = {}) ⇒ Array<(ScheduledTransactionResponse, Integer, Hash)>

Create a scheduled transaction Creates a single scheduled transaction (a transaction with a future date).

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • data (PostScheduledTransactionWrapper)

    The scheduled transaction to create

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 35

def create_scheduled_transaction_with_http_info(plan_id, data, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ScheduledTransactionsApi.create_scheduled_transaction ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling ScheduledTransactionsApi.create_scheduled_transaction"
  end
  # verify the required parameter 'data' is set
  if @api_client.config.client_side_validation && data.nil?
    fail ArgumentError, "Missing the required parameter 'data' when calling ScheduledTransactionsApi.create_scheduled_transaction"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/scheduled_transactions'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(data)

  # return_type
  return_type = opts[:debug_return_type] || 'ScheduledTransactionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"ScheduledTransactionsApi.create_scheduled_transaction",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ScheduledTransactionsApi#create_scheduled_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_scheduled_transaction(plan_id, scheduled_transaction_id, opts = {}) ⇒ ScheduledTransactionResponse

Delete a scheduled transaction Deletes a scheduled transaction

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • scheduled_transaction_id (String)

    The id of the scheduled transaction

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



98
99
100
101
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 98

def delete_scheduled_transaction(plan_id, scheduled_transaction_id, opts = {})
  data, _status_code, _headers = delete_scheduled_transaction_with_http_info(plan_id, scheduled_transaction_id, opts)
  data
end

#delete_scheduled_transaction_with_http_info(plan_id, scheduled_transaction_id, opts = {}) ⇒ Array<(ScheduledTransactionResponse, Integer, Hash)>

Delete a scheduled transaction Deletes a scheduled transaction

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • scheduled_transaction_id (String)

    The id of the scheduled transaction

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 109

def delete_scheduled_transaction_with_http_info(plan_id, scheduled_transaction_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ScheduledTransactionsApi.delete_scheduled_transaction ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling ScheduledTransactionsApi.delete_scheduled_transaction"
  end
  # verify the required parameter 'scheduled_transaction_id' is set
  if @api_client.config.client_side_validation && scheduled_transaction_id.nil?
    fail ArgumentError, "Missing the required parameter 'scheduled_transaction_id' when calling ScheduledTransactionsApi.delete_scheduled_transaction"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/scheduled_transactions/{scheduled_transaction_id}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'scheduled_transaction_id' + '}', CGI.escape(scheduled_transaction_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ScheduledTransactionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"ScheduledTransactionsApi.delete_scheduled_transaction",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ScheduledTransactionsApi#delete_scheduled_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_scheduled_transaction_by_id(plan_id, scheduled_transaction_id, opts = {}) ⇒ ScheduledTransactionResponse

Get a scheduled transaction Returns a single scheduled transaction

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • scheduled_transaction_id (String)

    The id of the scheduled transaction

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



167
168
169
170
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 167

def get_scheduled_transaction_by_id(plan_id, scheduled_transaction_id, opts = {})
  data, _status_code, _headers = get_scheduled_transaction_by_id_with_http_info(plan_id, scheduled_transaction_id, opts)
  data
end

#get_scheduled_transaction_by_id_with_http_info(plan_id, scheduled_transaction_id, opts = {}) ⇒ Array<(ScheduledTransactionResponse, Integer, Hash)>

Get a scheduled transaction Returns a single scheduled transaction

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • scheduled_transaction_id (String)

    The id of the scheduled transaction

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 178

def get_scheduled_transaction_by_id_with_http_info(plan_id, scheduled_transaction_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ScheduledTransactionsApi.get_scheduled_transaction_by_id ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling ScheduledTransactionsApi.get_scheduled_transaction_by_id"
  end
  # verify the required parameter 'scheduled_transaction_id' is set
  if @api_client.config.client_side_validation && scheduled_transaction_id.nil?
    fail ArgumentError, "Missing the required parameter 'scheduled_transaction_id' when calling ScheduledTransactionsApi.get_scheduled_transaction_by_id"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/scheduled_transactions/{scheduled_transaction_id}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'scheduled_transaction_id' + '}', CGI.escape(scheduled_transaction_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ScheduledTransactionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"ScheduledTransactionsApi.get_scheduled_transaction_by_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ScheduledTransactionsApi#get_scheduled_transaction_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_scheduled_transactions(plan_id, opts = {}) ⇒ ScheduledTransactionsResponse

Get all scheduled transactions Returns all scheduled transactions

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :last_knowledge_of_server (Integer)

    The starting server knowledge. If provided, only entities that have changed since &#x60;last_knowledge_of_server&#x60; will be included.

Returns:



236
237
238
239
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 236

def get_scheduled_transactions(plan_id, opts = {})
  data, _status_code, _headers = get_scheduled_transactions_with_http_info(plan_id, opts)
  data
end

#get_scheduled_transactions_with_http_info(plan_id, opts = {}) ⇒ Array<(ScheduledTransactionsResponse, Integer, Hash)>

Get all scheduled transactions Returns all scheduled transactions

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :last_knowledge_of_server (Integer)

    The starting server knowledge. If provided, only entities that have changed since &#x60;last_knowledge_of_server&#x60; will be included.

Returns:



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 247

def get_scheduled_transactions_with_http_info(plan_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ScheduledTransactionsApi.get_scheduled_transactions ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling ScheduledTransactionsApi.get_scheduled_transactions"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/scheduled_transactions'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'last_knowledge_of_server'] = opts[:'last_knowledge_of_server'] if !opts[:'last_knowledge_of_server'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ScheduledTransactionsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"ScheduledTransactionsApi.get_scheduled_transactions",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ScheduledTransactionsApi#get_scheduled_transactions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_scheduled_transaction(plan_id, scheduled_transaction_id, put_scheduled_transaction_wrapper, opts = {}) ⇒ ScheduledTransactionResponse

Update a scheduled transaction Updates a single scheduled transaction

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • scheduled_transaction_id (String)

    The id of the scheduled transaction

  • put_scheduled_transaction_wrapper (PutScheduledTransactionWrapper)

    The scheduled transaction to update

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



303
304
305
306
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 303

def update_scheduled_transaction(plan_id, scheduled_transaction_id, put_scheduled_transaction_wrapper, opts = {})
  data, _status_code, _headers = update_scheduled_transaction_with_http_info(plan_id, scheduled_transaction_id, put_scheduled_transaction_wrapper, opts)
  data
end

#update_scheduled_transaction_with_http_info(plan_id, scheduled_transaction_id, put_scheduled_transaction_wrapper, opts = {}) ⇒ Array<(ScheduledTransactionResponse, Integer, Hash)>

Update a scheduled transaction Updates a single scheduled transaction

Parameters:

  • plan_id (String)

    The id of the plan. &quot;last-used&quot; can be used to specify the last used plan and &quot;default&quot; can be used if default plan selection is enabled (see: api.ynab.com/#oauth-default-plan).

  • scheduled_transaction_id (String)

    The id of the scheduled transaction

  • put_scheduled_transaction_wrapper (PutScheduledTransactionWrapper)

    The scheduled transaction to update

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/ynab/api/scheduled_transactions_api.rb', line 315

def update_scheduled_transaction_with_http_info(plan_id, scheduled_transaction_id, put_scheduled_transaction_wrapper, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ScheduledTransactionsApi.update_scheduled_transaction ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling ScheduledTransactionsApi.update_scheduled_transaction"
  end
  # verify the required parameter 'scheduled_transaction_id' is set
  if @api_client.config.client_side_validation && scheduled_transaction_id.nil?
    fail ArgumentError, "Missing the required parameter 'scheduled_transaction_id' when calling ScheduledTransactionsApi.update_scheduled_transaction"
  end
  # verify the required parameter 'put_scheduled_transaction_wrapper' is set
  if @api_client.config.client_side_validation && put_scheduled_transaction_wrapper.nil?
    fail ArgumentError, "Missing the required parameter 'put_scheduled_transaction_wrapper' when calling ScheduledTransactionsApi.update_scheduled_transaction"
  end
  # resource path
  local_var_path = '/plans/{plan_id}/scheduled_transactions/{scheduled_transaction_id}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'scheduled_transaction_id' + '}', CGI.escape(scheduled_transaction_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(put_scheduled_transaction_wrapper)

  # return_type
  return_type = opts[:debug_return_type] || 'ScheduledTransactionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer']

  new_options = opts.merge(
    :operation => :"ScheduledTransactionsApi.update_scheduled_transaction",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ScheduledTransactionsApi#update_scheduled_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end