Class: YNAB::TransactionDetail

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/transaction_detail.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TransactionDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/ynab/models/transaction_detail.rb', line 179

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::TransactionDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::TransactionDetail`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'memo')
    self.memo = attributes[:'memo']
  end

  if attributes.key?(:'cleared')
    self.cleared = attributes[:'cleared']
  end

  if attributes.key?(:'approved')
    self.approved = attributes[:'approved']
  end

  if attributes.key?(:'flag_color')
    self.flag_color = attributes[:'flag_color']
  end

  if attributes.key?(:'flag_name')
    self.flag_name = attributes[:'flag_name']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'payee_id')
    self.payee_id = attributes[:'payee_id']
  end

  if attributes.key?(:'category_id')
    self.category_id = attributes[:'category_id']
  end

  if attributes.key?(:'transfer_account_id')
    self. = attributes[:'transfer_account_id']
  end

  if attributes.key?(:'transfer_transaction_id')
    self.transfer_transaction_id = attributes[:'transfer_transaction_id']
  end

  if attributes.key?(:'matched_transaction_id')
    self.matched_transaction_id = attributes[:'matched_transaction_id']
  end

  if attributes.key?(:'import_id')
    self.import_id = attributes[:'import_id']
  end

  if attributes.key?(:'import_payee_name')
    self.import_payee_name = attributes[:'import_payee_name']
  end

  if attributes.key?(:'import_payee_name_original')
    self.import_payee_name_original = attributes[:'import_payee_name_original']
  end

  if attributes.key?(:'debt_transaction_type')
    self.debt_transaction_type = attributes[:'debt_transaction_type']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'account_name')
    self. = attributes[:'account_name']
  end

  if attributes.key?(:'payee_name')
    self.payee_name = attributes[:'payee_name']
  end

  if attributes.key?(:'category_name')
    self.category_name = attributes[:'category_name']
  end

  if attributes.key?(:'subtransactions')
    if (value = attributes[:'subtransactions']).is_a?(Array)
      self.subtransactions = value
    end
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



35
36
37
# File 'lib/ynab/models/transaction_detail.rb', line 35

def 
  @account_id
end

#account_nameObject

Returns the value of attribute account_name.



65
66
67
# File 'lib/ynab/models/transaction_detail.rb', line 65

def 
  @account_name
end

#amountObject

The transaction amount in milliunits format



21
22
23
# File 'lib/ynab/models/transaction_detail.rb', line 21

def amount
  @amount
end

#approvedObject

Whether or not the transaction is approved



28
29
30
# File 'lib/ynab/models/transaction_detail.rb', line 28

def approved
  @approved
end

#category_idObject

Returns the value of attribute category_id.



39
40
41
# File 'lib/ynab/models/transaction_detail.rb', line 39

def category_id
  @category_id
end

#category_nameObject

The name of the category. If a split transaction, this will be ‘Split’.



70
71
72
# File 'lib/ynab/models/transaction_detail.rb', line 70

def category_name
  @category_name
end

#clearedObject

Returns the value of attribute cleared.



25
26
27
# File 'lib/ynab/models/transaction_detail.rb', line 25

def cleared
  @cleared
end

#dateObject

The transaction date in ISO format (e.g. 2016-12-01)



18
19
20
# File 'lib/ynab/models/transaction_detail.rb', line 18

def date
  @date
end

#debt_transaction_typeObject

If the transaction is a debt/loan account transaction, the type of transaction



60
61
62
# File 'lib/ynab/models/transaction_detail.rb', line 60

def debt_transaction_type
  @debt_transaction_type
end

#deletedObject

Whether or not the transaction has been deleted. Deleted transactions will only be included in delta requests.



63
64
65
# File 'lib/ynab/models/transaction_detail.rb', line 63

def deleted
  @deleted
end

#flag_colorObject

Returns the value of attribute flag_color.



30
31
32
# File 'lib/ynab/models/transaction_detail.rb', line 30

def flag_color
  @flag_color
end

#flag_nameObject

The customized name of a transaction flag



33
34
35
# File 'lib/ynab/models/transaction_detail.rb', line 33

def flag_name
  @flag_name
end

#idObject

Returns the value of attribute id.



15
16
17
# File 'lib/ynab/models/transaction_detail.rb', line 15

def id
  @id
end

#import_idObject

If the transaction was imported, this field is a unique (by account) import identifier. If this transaction was imported through File Based Import or Direct Import and not through the API, the import_id will have the format: ‘YNAB::[iso_date]:’. For example, a transaction dated 2015-12-30 in the amount of -$294.23 USD would have an import_id of ‘YNAB:-294230:2015-12-30:1’. If a second transaction on the same account was imported and had the same date and same amount, its import_id would be ‘YNAB:-294230:2015-12-30:2’.



51
52
53
# File 'lib/ynab/models/transaction_detail.rb', line 51

def import_id
  @import_id
end

#import_payee_nameObject

If the transaction was imported, the payee name that was used when importing and before applying any payee rename rules



54
55
56
# File 'lib/ynab/models/transaction_detail.rb', line 54

def import_payee_name
  @import_payee_name
end

#import_payee_name_originalObject

If the transaction was imported, the original payee name as it appeared on the statement



57
58
59
# File 'lib/ynab/models/transaction_detail.rb', line 57

def import_payee_name_original
  @import_payee_name_original
end

#matched_transaction_idObject

If transaction is matched, the id of the matched transaction



48
49
50
# File 'lib/ynab/models/transaction_detail.rb', line 48

def matched_transaction_id
  @matched_transaction_id
end

#memoObject

Returns the value of attribute memo.



23
24
25
# File 'lib/ynab/models/transaction_detail.rb', line 23

def memo
  @memo
end

#payee_idObject

Returns the value of attribute payee_id.



37
38
39
# File 'lib/ynab/models/transaction_detail.rb', line 37

def payee_id
  @payee_id
end

#payee_nameObject

Returns the value of attribute payee_name.



67
68
69
# File 'lib/ynab/models/transaction_detail.rb', line 67

def payee_name
  @payee_name
end

#subtransactionsObject

If a split transaction, the subtransactions.



73
74
75
# File 'lib/ynab/models/transaction_detail.rb', line 73

def subtransactions
  @subtransactions
end

#transfer_account_idObject

If a transfer transaction, the account to which it transfers



42
43
44
# File 'lib/ynab/models/transaction_detail.rb', line 42

def 
  @transfer_account_id
end

#transfer_transaction_idObject

If a transfer transaction, the id of transaction on the other side of the transfer



45
46
47
# File 'lib/ynab/models/transaction_detail.rb', line 45

def transfer_transaction_id
  @transfer_transaction_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



127
128
129
# File 'lib/ynab/models/transaction_detail.rb', line 127

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/ynab/models/transaction_detail.rb', line 98

def self.attribute_map
  {
    :'id' => :'id',
    :'date' => :'date',
    :'amount' => :'amount',
    :'memo' => :'memo',
    :'cleared' => :'cleared',
    :'approved' => :'approved',
    :'flag_color' => :'flag_color',
    :'flag_name' => :'flag_name',
    :'account_id' => :'account_id',
    :'payee_id' => :'payee_id',
    :'category_id' => :'category_id',
    :'transfer_account_id' => :'transfer_account_id',
    :'transfer_transaction_id' => :'transfer_transaction_id',
    :'matched_transaction_id' => :'matched_transaction_id',
    :'import_id' => :'import_id',
    :'import_payee_name' => :'import_payee_name',
    :'import_payee_name_original' => :'import_payee_name_original',
    :'debt_transaction_type' => :'debt_transaction_type',
    :'deleted' => :'deleted',
    :'account_name' => :'account_name',
    :'payee_name' => :'payee_name',
    :'category_name' => :'category_name',
    :'subtransactions' => :'subtransactions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/ynab/models/transaction_detail.rb', line 362

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



171
172
173
174
175
# File 'lib/ynab/models/transaction_detail.rb', line 171

def self.openapi_all_of
  [
  :'TransactionSummary'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



161
162
163
164
165
166
167
168
# File 'lib/ynab/models/transaction_detail.rb', line 161

def self.openapi_nullable
  Set.new([
    :'flag_color',
    :'debt_transaction_type',
    :'payee_name',
    :'category_name',
  ])
end

.openapi_typesObject

Attribute type mapping.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/ynab/models/transaction_detail.rb', line 132

def self.openapi_types
  {
    :'id' => :'String',
    :'date' => :'Date',
    :'amount' => :'Integer',
    :'memo' => :'String',
    :'cleared' => :'TransactionClearedStatus',
    :'approved' => :'Boolean',
    :'flag_color' => :'TransactionFlagColor',
    :'flag_name' => :'String',
    :'account_id' => :'String',
    :'payee_id' => :'String',
    :'category_id' => :'String',
    :'transfer_account_id' => :'String',
    :'transfer_transaction_id' => :'String',
    :'matched_transaction_id' => :'String',
    :'import_id' => :'String',
    :'import_payee_name' => :'String',
    :'import_payee_name_original' => :'String',
    :'debt_transaction_type' => :'String',
    :'deleted' => :'Boolean',
    :'account_name' => :'String',
    :'payee_name' => :'String',
    :'category_name' => :'String',
    :'subtransactions' => :'Array<SubTransaction>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/ynab/models/transaction_detail.rb', line 319

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      date == o.date &&
      amount == o.amount &&
      memo == o.memo &&
      cleared == o.cleared &&
      approved == o.approved &&
      flag_color == o.flag_color &&
      flag_name == o.flag_name &&
       == o. &&
      payee_id == o.payee_id &&
      category_id == o.category_id &&
       == o. &&
      transfer_transaction_id == o.transfer_transaction_id &&
      matched_transaction_id == o.matched_transaction_id &&
      import_id == o.import_id &&
      import_payee_name == o.import_payee_name &&
      import_payee_name_original == o.import_payee_name_original &&
      debt_transaction_type == o.debt_transaction_type &&
      deleted == o.deleted &&
       == o. &&
      payee_name == o.payee_name &&
      category_name == o.category_name &&
      subtransactions == o.subtransactions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


349
350
351
# File 'lib/ynab/models/transaction_detail.rb', line 349

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



355
356
357
# File 'lib/ynab/models/transaction_detail.rb', line 355

def hash
  [id, date, amount, memo, cleared, approved, flag_color, flag_name, , payee_id, category_id, , transfer_transaction_id, matched_transaction_id, import_id, import_payee_name, import_payee_name_original, debt_transaction_type, deleted, , payee_name, category_name, subtransactions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



289
290
291
292
# File 'lib/ynab/models/transaction_detail.rb', line 289

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/ynab/models/transaction_detail.rb', line 384

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/ynab/models/transaction_detail.rb', line 296

def valid?
  return false if @id.nil?
  return false if @date.nil?
  return false if @amount.nil?
  return false if @cleared.nil?
  return false if @approved.nil?
  return false if @account_id.nil?
  debt_transaction_type_validator = EnumAttributeValidator.new('String', ["payment", "refund", "fee", "interest", "escrow", "balanceAdjustment", "credit", "charge"])
  return false unless debt_transaction_type_validator.valid?(@debt_transaction_type)
  return false if @deleted.nil?
  return false if @account_name.nil?
  return false if @subtransactions.nil?
  true
end