Class: YNAB::UpdateTransaction

Inherits:
Object
  • Object
show all
Defined in:
lib/ynab/models/update_transaction.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/ynab/models/update_transaction.rb', line 110

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.has_key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.has_key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.has_key?(:'payee_id')
    self.payee_id = attributes[:'payee_id']
  end

  if attributes.has_key?(:'payee_name')
    self.payee_name = attributes[:'payee_name']
  end

  if attributes.has_key?(:'category_id')
    self.category_id = attributes[:'category_id']
  end

  if attributes.has_key?(:'memo')
    self.memo = attributes[:'memo']
  end

  if attributes.has_key?(:'cleared')
    self.cleared = attributes[:'cleared']
  end

  if attributes.has_key?(:'approved')
    self.approved = attributes[:'approved']
  end

  if attributes.has_key?(:'flag_color')
    self.flag_color = attributes[:'flag_color']
  end

  if attributes.has_key?(:'import_id')
    self.import_id = attributes[:'import_id']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



17
18
19
# File 'lib/ynab/models/update_transaction.rb', line 17

def 
  @account_id
end

#amountObject

The transaction amount in milliunits format. Split transaction amounts cannot be changed and if a different amount is supplied it will be ignored.



23
24
25
# File 'lib/ynab/models/update_transaction.rb', line 23

def amount
  @amount
end

#approvedObject

Whether or not the transaction is approved. If not supplied, transaction will be unapproved by default.



40
41
42
# File 'lib/ynab/models/update_transaction.rb', line 40

def approved
  @approved
end

#category_idObject

The category for the transaction. Split and Credit Card Payment categories are not permitted and will be ignored if supplied. If an existing transaction has a Split category it cannot be changed.



32
33
34
# File 'lib/ynab/models/update_transaction.rb', line 32

def category_id
  @category_id
end

#clearedObject

The cleared status of the transaction



37
38
39
# File 'lib/ynab/models/update_transaction.rb', line 37

def cleared
  @cleared
end

#dateObject

The transaction date in ISO format (e.g. 2016-12-01). Future dates (scheduled transactions) are not permitted. Split transaction dates cannot be changed and if a different date is supplied it will be ignored.



20
21
22
# File 'lib/ynab/models/update_transaction.rb', line 20

def date
  @date
end

#flag_colorObject

The transaction flag



43
44
45
# File 'lib/ynab/models/update_transaction.rb', line 43

def flag_color
  @flag_color
end

#idObject

Returns the value of attribute id.



48
49
50
# File 'lib/ynab/models/update_transaction.rb', line 48

def id
  @id
end

#import_idObject

If specified, the new transaction will be assigned this import_id and considered "imported". We will also attempt to match this imported transaction to an existing "user-entered" transation on the same account, with the same amount, and with a date +/-10 days from the imported transaction date.
Transactions imported through File Based Import or Direct Import (not through the API) are assigned an import_id in the format: ‘YNAB::[iso_date]:’. For example, a transaction dated 2015-12-30 in the amount of -$294.23 USD would have an import_id of ‘YNAB:-294230:2015-12-30:1’. If a second transaction on the same account was imported and had the same date and same amount, its import_id would be ‘YNAB:-294230:2015-12-30:2’. Using a consistent format will prevent duplicates through Direct Import and File Based Import.
If import_id is omitted or specified as null, the transaction will be treated as a "user-entered" transaction. As such, it will be eligible to be matched against transactions later being imported (via DI, FBI, or API).



46
47
48
# File 'lib/ynab/models/update_transaction.rb', line 46

def import_id
  @import_id
end

#memoObject

Returns the value of attribute memo.



34
35
36
# File 'lib/ynab/models/update_transaction.rb', line 34

def memo
  @memo
end

#payee_idObject

The payee for the transaction. To create a transfer between two accounts, use the account transfer payee pointing to the target account. Account transfer payees are specified as tranfer_payee_id on the account resource.



26
27
28
# File 'lib/ynab/models/update_transaction.rb', line 26

def payee_id
  @payee_id
end

#payee_nameObject

The payee name. If a payee_name value is provided and payee_id has a null value, the payee_name value will be used to resolve the payee by either (1) a matching payee rename rule (only if import_id is also specified) or (2) a payee with the same name or (3) creation of a new payee.



29
30
31
# File 'lib/ynab/models/update_transaction.rb', line 29

def payee_name
  @payee_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/ynab/models/update_transaction.rb', line 73

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'date' => :'date',
    :'amount' => :'amount',
    :'payee_id' => :'payee_id',
    :'payee_name' => :'payee_name',
    :'category_id' => :'category_id',
    :'memo' => :'memo',
    :'cleared' => :'cleared',
    :'approved' => :'approved',
    :'flag_color' => :'flag_color',
    :'import_id' => :'import_id',
    :'id' => :'id'
  }
end

.swagger_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/ynab/models/update_transaction.rb', line 91

def self.swagger_types
  {
    :'account_id' => :'String',
    :'date' => :'Date',
    :'amount' => :'Integer',
    :'payee_id' => :'String',
    :'payee_name' => :'String',
    :'category_id' => :'String',
    :'memo' => :'String',
    :'cleared' => :'String',
    :'approved' => :'BOOLEAN',
    :'flag_color' => :'String',
    :'import_id' => :'String',
    :'id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/ynab/models/update_transaction.rb', line 269

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      date == o.date &&
      amount == o.amount &&
      payee_id == o.payee_id &&
      payee_name == o.payee_name &&
      category_id == o.category_id &&
      memo == o.memo &&
      cleared == o.cleared &&
      approved == o.approved &&
      flag_color == o.flag_color &&
      import_id == o.import_id &&
      id == o.id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/ynab/models/update_transaction.rb', line 322

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = YNAB.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/ynab/models/update_transaction.rb', line 388

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/ynab/models/update_transaction.rb', line 301

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


288
289
290
# File 'lib/ynab/models/update_transaction.rb', line 288

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



294
295
296
# File 'lib/ynab/models/update_transaction.rb', line 294

def hash
  [, date, amount, payee_id, payee_name, category_id, memo, cleared, approved, flag_color, import_id, id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/ynab/models/update_transaction.rb', line 167

def list_invalid_properties
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if !@payee_name.nil? && @payee_name.to_s.length > 50
    invalid_properties.push('invalid value for "payee_name", the character length must be smaller than or equal to 50.')
  end

  if !@memo.nil? && @memo.to_s.length > 200
    invalid_properties.push('invalid value for "memo", the character length must be smaller than or equal to 200.')
  end

  if !@import_id.nil? && @import_id.to_s.length > 36
    invalid_properties.push('invalid value for "import_id", the character length must be smaller than or equal to 36.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
# File 'lib/ynab/models/update_transaction.rb', line 368

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



374
375
376
377
378
379
380
381
382
# File 'lib/ynab/models/update_transaction.rb', line 374

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



362
363
364
# File 'lib/ynab/models/update_transaction.rb', line 362

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/ynab/models/update_transaction.rb', line 202

def valid?
  return false if @account_id.nil?
  return false if @date.nil?
  return false if @amount.nil?
  return false if !@payee_name.nil? && @payee_name.to_s.length > 50
  return false if !@memo.nil? && @memo.to_s.length > 200
  cleared_validator = EnumAttributeValidator.new('String', ['cleared', 'uncleared', 'reconciled'])
  return false unless cleared_validator.valid?(@cleared)
  flag_color_validator = EnumAttributeValidator.new('String', ['red', 'orange', 'yellow', 'green', 'blue', 'purple'])
  return false unless flag_color_validator.valid?(@flag_color)
  return false if !@import_id.nil? && @import_id.to_s.length > 36
  return false if @id.nil?
  true
end