Class: YNAB::CategoryGroupWithCategories
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::CategoryGroupWithCategories
- Defined in:
- lib/ynab/models/category_group_with_categories.rb
Instance Attribute Summary collapse
-
#categories ⇒ Object
Category group categories.
-
#deleted ⇒ Object
Whether or not the category group has been deleted.
-
#hidden ⇒ Object
Whether or not the category group is hidden.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CategoryGroupWithCategories
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CategoryGroupWithCategories
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 70 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::CategoryGroupWithCategories` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::CategoryGroupWithCategories`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'hidden') self.hidden = attributes[:'hidden'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'categories') if (value = attributes[:'categories']).is_a?(Array) self.categories = value end end end |
Instance Attribute Details
#categories ⇒ Object
Category group categories. Amounts (assigned, activity, available, etc.) are specific to the current plan month (UTC).
26 27 28 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 26 def categories @categories end |
#deleted ⇒ Object
Whether or not the category group has been deleted. Deleted category groups will only be included in delta requests.
23 24 25 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 23 def deleted @deleted end |
#hidden ⇒ Object
Whether or not the category group is hidden
20 21 22 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 20 def hidden @hidden end |
#id ⇒ Object
Returns the value of attribute id.
15 16 17 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 15 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
17 18 19 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 17 def name @name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 40 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 29 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'hidden' => :'hidden', :'deleted' => :'deleted', :'categories' => :'categories' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
62 63 64 65 66 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 62 def self.openapi_all_of [ :'CategoryGroup' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 45 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'hidden' => :'Boolean', :'deleted' => :'Boolean', :'categories' => :'Array<Category>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 126 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && hidden == o.hidden && deleted == o.deleted && categories == o.categories end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 144 def hash [id, name, hidden, deleted, categories].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 108 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
115 116 117 118 119 120 121 122 |
# File 'lib/ynab/models/category_group_with_categories.rb', line 115 def valid? return false if @id.nil? return false if @name.nil? return false if @hidden.nil? return false if @deleted.nil? return false if @categories.nil? true end |