Class: YNAB::MoneyMovementGroup
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::MoneyMovementGroup
- Defined in:
- lib/ynab/models/money_movement_group.rb
Instance Attribute Summary collapse
-
#group_created_at ⇒ Object
When the money movement group was created.
-
#id ⇒ Object
Returns the value of attribute id.
-
#month ⇒ Object
The month of the money movement group in ISO format (e.g. 2024-01-01).
-
#note ⇒ Object
Returns the value of attribute note.
-
#performed_by_user_id ⇒ Object
The id of the user who performed the money movement group.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MoneyMovementGroup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MoneyMovementGroup
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/ynab/models/money_movement_group.rb', line 65 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::MoneyMovementGroup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::MoneyMovementGroup`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'group_created_at') self.group_created_at = attributes[:'group_created_at'] end if attributes.key?(:'month') self.month = attributes[:'month'] end if attributes.key?(:'note') self.note = attributes[:'note'] end if attributes.key?(:'performed_by_user_id') self.performed_by_user_id = attributes[:'performed_by_user_id'] end end |
Instance Attribute Details
#group_created_at ⇒ Object
When the money movement group was created
18 19 20 |
# File 'lib/ynab/models/money_movement_group.rb', line 18 def group_created_at @group_created_at end |
#id ⇒ Object
Returns the value of attribute id.
15 16 17 |
# File 'lib/ynab/models/money_movement_group.rb', line 15 def id @id end |
#month ⇒ Object
The month of the money movement group in ISO format (e.g. 2024-01-01)
21 22 23 |
# File 'lib/ynab/models/money_movement_group.rb', line 21 def month @month end |
#note ⇒ Object
Returns the value of attribute note.
23 24 25 |
# File 'lib/ynab/models/money_movement_group.rb', line 23 def note @note end |
#performed_by_user_id ⇒ Object
The id of the user who performed the money movement group
26 27 28 |
# File 'lib/ynab/models/money_movement_group.rb', line 26 def performed_by_user_id @performed_by_user_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/ynab/models/money_movement_group.rb', line 40 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/ynab/models/money_movement_group.rb', line 29 def self.attribute_map { :'id' => :'id', :'group_created_at' => :'group_created_at', :'month' => :'month', :'note' => :'note', :'performed_by_user_id' => :'performed_by_user_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/ynab/models/money_movement_group.rb', line 142 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 60 61 |
# File 'lib/ynab/models/money_movement_group.rb', line 56 def self.openapi_nullable Set.new([ :'note', :'performed_by_user_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 |
# File 'lib/ynab/models/money_movement_group.rb', line 45 def self.openapi_types { :'id' => :'String', :'group_created_at' => :'Time', :'month' => :'Date', :'note' => :'String', :'performed_by_user_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 |
# File 'lib/ynab/models/money_movement_group.rb', line 117 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && group_created_at == o.group_created_at && month == o.month && note == o.note && performed_by_user_id == o.performed_by_user_id end |
#eql?(o) ⇒ Boolean
129 130 131 |
# File 'lib/ynab/models/money_movement_group.rb', line 129 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
135 136 137 |
# File 'lib/ynab/models/money_movement_group.rb', line 135 def hash [id, group_created_at, month, note, performed_by_user_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
101 102 103 104 |
# File 'lib/ynab/models/money_movement_group.rb', line 101 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/ynab/models/money_movement_group.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
108 109 110 111 112 113 |
# File 'lib/ynab/models/money_movement_group.rb', line 108 def valid? return false if @id.nil? return false if @group_created_at.nil? return false if @month.nil? true end |