Class: YNAB::MonthSummary

Inherits:
ApiModelBase show all
Defined in:
lib/ynab/models/month_summary.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MonthSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/ynab/models/month_summary.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::MonthSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::MonthSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'month')
    self.month = attributes[:'month']
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end

  if attributes.key?(:'income')
    self.income = attributes[:'income']
  end

  if attributes.key?(:'budgeted')
    self.budgeted = attributes[:'budgeted']
  end

  if attributes.key?(:'activity')
    self.activity = attributes[:'activity']
  end

  if attributes.key?(:'to_be_budgeted')
    self.to_be_budgeted = attributes[:'to_be_budgeted']
  end

  if attributes.key?(:'age_of_money')
    self.age_of_money = attributes[:'age_of_money']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'income_formatted')
    self.income_formatted = attributes[:'income_formatted']
  end

  if attributes.key?(:'income_currency')
    self.income_currency = attributes[:'income_currency']
  end

  if attributes.key?(:'budgeted_formatted')
    self.budgeted_formatted = attributes[:'budgeted_formatted']
  end

  if attributes.key?(:'budgeted_currency')
    self.budgeted_currency = attributes[:'budgeted_currency']
  end

  if attributes.key?(:'activity_formatted')
    self.activity_formatted = attributes[:'activity_formatted']
  end

  if attributes.key?(:'activity_currency')
    self.activity_currency = attributes[:'activity_currency']
  end

  if attributes.key?(:'to_be_budgeted_formatted')
    self.to_be_budgeted_formatted = attributes[:'to_be_budgeted_formatted']
  end

  if attributes.key?(:'to_be_budgeted_currency')
    self.to_be_budgeted_currency = attributes[:'to_be_budgeted_currency']
  end
end

Instance Attribute Details

#activityObject

The total amount of transactions in the month, excluding those categorized to ‘Inflow: Ready to Assign’



26
27
28
# File 'lib/ynab/models/month_summary.rb', line 26

def activity
  @activity
end

#activity_currencyObject

The total activity amount as a decimal currency amount



53
54
55
# File 'lib/ynab/models/month_summary.rb', line 53

def activity_currency
  @activity_currency
end

#activity_formattedObject

The total activity amount formatted in the plan’s currency format



50
51
52
# File 'lib/ynab/models/month_summary.rb', line 50

def activity_formatted
  @activity_formatted
end

#age_of_moneyObject

The Age of Money as of the month



32
33
34
# File 'lib/ynab/models/month_summary.rb', line 32

def age_of_money
  @age_of_money
end

#budgetedObject

The total amount assigned (budgeted) in the month



23
24
25
# File 'lib/ynab/models/month_summary.rb', line 23

def budgeted
  @budgeted
end

#budgeted_currencyObject

The total amount assigned as a decimal currency amount



47
48
49
# File 'lib/ynab/models/month_summary.rb', line 47

def budgeted_currency
  @budgeted_currency
end

#budgeted_formattedObject

The total amount assigned formatted in the plan’s currency format



44
45
46
# File 'lib/ynab/models/month_summary.rb', line 44

def budgeted_formatted
  @budgeted_formatted
end

#deletedObject

Whether or not the month has been deleted. Deleted months will only be included in delta requests.



35
36
37
# File 'lib/ynab/models/month_summary.rb', line 35

def deleted
  @deleted
end

#incomeObject

The total amount of transactions categorized to ‘Inflow: Ready to Assign’ in the month



20
21
22
# File 'lib/ynab/models/month_summary.rb', line 20

def income
  @income
end

#income_currencyObject

The total income as a decimal currency amount



41
42
43
# File 'lib/ynab/models/month_summary.rb', line 41

def income_currency
  @income_currency
end

#income_formattedObject

The total income formatted in the plan’s currency format



38
39
40
# File 'lib/ynab/models/month_summary.rb', line 38

def income_formatted
  @income_formatted
end

#monthObject

Returns the value of attribute month.



15
16
17
# File 'lib/ynab/models/month_summary.rb', line 15

def month
  @month
end

#noteObject

Returns the value of attribute note.



17
18
19
# File 'lib/ynab/models/month_summary.rb', line 17

def note
  @note
end

#to_be_budgetedObject

The available amount for ‘Ready to Assign’



29
30
31
# File 'lib/ynab/models/month_summary.rb', line 29

def to_be_budgeted
  @to_be_budgeted
end

#to_be_budgeted_currencyObject

The available amount for ‘Ready to Assign’ as a decimal currency amount



59
60
61
# File 'lib/ynab/models/month_summary.rb', line 59

def to_be_budgeted_currency
  @to_be_budgeted_currency
end

#to_be_budgeted_formattedObject

The available amount for ‘Ready to Assign’ formatted in the plan’s currency format



56
57
58
# File 'lib/ynab/models/month_summary.rb', line 56

def to_be_budgeted_formatted
  @to_be_budgeted_formatted
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/ynab/models/month_summary.rb', line 84

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/ynab/models/month_summary.rb', line 62

def self.attribute_map
  {
    :'month' => :'month',
    :'note' => :'note',
    :'income' => :'income',
    :'budgeted' => :'budgeted',
    :'activity' => :'activity',
    :'to_be_budgeted' => :'to_be_budgeted',
    :'age_of_money' => :'age_of_money',
    :'deleted' => :'deleted',
    :'income_formatted' => :'income_formatted',
    :'income_currency' => :'income_currency',
    :'budgeted_formatted' => :'budgeted_formatted',
    :'budgeted_currency' => :'budgeted_currency',
    :'activity_formatted' => :'activity_formatted',
    :'activity_currency' => :'activity_currency',
    :'to_be_budgeted_formatted' => :'to_be_budgeted_formatted',
    :'to_be_budgeted_currency' => :'to_be_budgeted_currency'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/ynab/models/month_summary.rb', line 260

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



117
118
119
120
121
# File 'lib/ynab/models/month_summary.rb', line 117

def self.openapi_all_of
  [
  :'MonthSummaryBase'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/ynab/models/month_summary.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/ynab/models/month_summary.rb', line 89

def self.openapi_types
  {
    :'month' => :'Date',
    :'note' => :'String',
    :'income' => :'Integer',
    :'budgeted' => :'Integer',
    :'activity' => :'Integer',
    :'to_be_budgeted' => :'Integer',
    :'age_of_money' => :'Integer',
    :'deleted' => :'Boolean',
    :'income_formatted' => :'String',
    :'income_currency' => :'Float',
    :'budgeted_formatted' => :'String',
    :'budgeted_currency' => :'Float',
    :'activity_formatted' => :'String',
    :'activity_currency' => :'Float',
    :'to_be_budgeted_formatted' => :'String',
    :'to_be_budgeted_currency' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/ynab/models/month_summary.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      month == o.month &&
      note == o.note &&
      income == o.income &&
      budgeted == o.budgeted &&
      activity == o.activity &&
      to_be_budgeted == o.to_be_budgeted &&
      age_of_money == o.age_of_money &&
      deleted == o.deleted &&
      income_formatted == o.income_formatted &&
      income_currency == o.income_currency &&
      budgeted_formatted == o.budgeted_formatted &&
      budgeted_currency == o.budgeted_currency &&
      activity_formatted == o.activity_formatted &&
      activity_currency == o.activity_currency &&
      to_be_budgeted_formatted == o.to_be_budgeted_formatted &&
      to_be_budgeted_currency == o.to_be_budgeted_currency
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/ynab/models/month_summary.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



253
254
255
# File 'lib/ynab/models/month_summary.rb', line 253

def hash
  [month, note, income, budgeted, activity, to_be_budgeted, age_of_money, deleted, income_formatted, income_currency, budgeted_formatted, budgeted_currency, activity_formatted, activity_currency, to_be_budgeted_formatted, to_be_budgeted_currency].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
# File 'lib/ynab/models/month_summary.rb', line 205

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/ynab/models/month_summary.rb', line 282

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
220
# File 'lib/ynab/models/month_summary.rb', line 212

def valid?
  return false if @month.nil?
  return false if @income.nil?
  return false if @budgeted.nil?
  return false if @activity.nil?
  return false if @to_be_budgeted.nil?
  return false if @deleted.nil?
  true
end