Class: YNAB::MonthsApi
- Inherits:
-
Object
- Object
- YNAB::MonthsApi
- Defined in:
- lib/ynab/api/months_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_plan_month(plan_id, month, opts = {}) ⇒ MonthDetailResponse
Get a plan month Returns a single plan month.
-
#get_plan_month_with_http_info(plan_id, month, opts = {}) ⇒ Array<(MonthDetailResponse, Integer, Hash)>
Get a plan month Returns a single plan month.
-
#get_plan_months(plan_id, opts = {}) ⇒ MonthSummariesResponse
Get all plan months Returns all plan months.
-
#get_plan_months_with_http_info(plan_id, opts = {}) ⇒ Array<(MonthSummariesResponse, Integer, Hash)>
Get all plan months Returns all plan months.
-
#initialize(api_client = ApiClient.default) ⇒ MonthsApi
constructor
A new instance of MonthsApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/ynab/api/months_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#get_plan_month(plan_id, month, opts = {}) ⇒ MonthDetailResponse
Get a plan month Returns a single plan month
24 25 26 27 |
# File 'lib/ynab/api/months_api.rb', line 24 def get_plan_month(plan_id, month, opts = {}) data, _status_code, _headers = get_plan_month_with_http_info(plan_id, month, opts) data end |
#get_plan_month_with_http_info(plan_id, month, opts = {}) ⇒ Array<(MonthDetailResponse, Integer, Hash)>
Get a plan month Returns a single plan month
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/ynab/api/months_api.rb', line 35 def get_plan_month_with_http_info(plan_id, month, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MonthsApi.get_plan_month ...' end # verify the required parameter 'plan_id' is set if @api_client.config.client_side_validation && plan_id.nil? fail ArgumentError, "Missing the required parameter 'plan_id' when calling MonthsApi.get_plan_month" end # verify the required parameter 'month' is set if @api_client.config.client_side_validation && month.nil? fail ArgumentError, "Missing the required parameter 'month' when calling MonthsApi.get_plan_month" end # resource path local_var_path = '/plans/{plan_id}/months/{month}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'month' + '}', CGI.escape(month.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MonthDetailResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer'] = opts.merge( :operation => :"MonthsApi.get_plan_month", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MonthsApi#get_plan_month\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_plan_months(plan_id, opts = {}) ⇒ MonthSummariesResponse
Get all plan months Returns all plan months
93 94 95 96 |
# File 'lib/ynab/api/months_api.rb', line 93 def get_plan_months(plan_id, opts = {}) data, _status_code, _headers = get_plan_months_with_http_info(plan_id, opts) data end |
#get_plan_months_with_http_info(plan_id, opts = {}) ⇒ Array<(MonthSummariesResponse, Integer, Hash)>
Get all plan months Returns all plan months
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/ynab/api/months_api.rb', line 104 def get_plan_months_with_http_info(plan_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MonthsApi.get_plan_months ...' end # verify the required parameter 'plan_id' is set if @api_client.config.client_side_validation && plan_id.nil? fail ArgumentError, "Missing the required parameter 'plan_id' when calling MonthsApi.get_plan_months" end # resource path local_var_path = '/plans/{plan_id}/months'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'last_knowledge_of_server'] = opts[:'last_knowledge_of_server'] if !opts[:'last_knowledge_of_server'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MonthSummariesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer'] = opts.merge( :operation => :"MonthsApi.get_plan_months", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MonthsApi#get_plan_months\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |