Class: YNAB::PlanSummary
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::PlanSummary
- Defined in:
- lib/ynab/models/plan_summary.rb
Instance Attribute Summary collapse
-
#accounts ⇒ Object
The plan accounts (only included if ‘include_accounts=true` specified as query parameter).
-
#currency_format ⇒ Object
Returns the value of attribute currency_format.
-
#date_format ⇒ Object
Returns the value of attribute date_format.
-
#first_month ⇒ Object
The earliest plan month.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_modified_on ⇒ Object
The last time any changes were made to the plan from either a web or mobile client.
-
#last_month ⇒ Object
The latest plan month.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PlanSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PlanSummary
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/ynab/models/plan_summary.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::PlanSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::PlanSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'last_modified_on') self.last_modified_on = attributes[:'last_modified_on'] end if attributes.key?(:'first_month') self.first_month = attributes[:'first_month'] end if attributes.key?(:'last_month') self.last_month = attributes[:'last_month'] end if attributes.key?(:'date_format') self.date_format = attributes[:'date_format'] end if attributes.key?(:'currency_format') self.currency_format = attributes[:'currency_format'] end if attributes.key?(:'accounts') if (value = attributes[:'accounts']).is_a?(Array) self.accounts = value end end end |
Instance Attribute Details
#accounts ⇒ Object
The plan accounts (only included if ‘include_accounts=true` specified as query parameter)
33 34 35 |
# File 'lib/ynab/models/plan_summary.rb', line 33 def accounts @accounts end |
#currency_format ⇒ Object
Returns the value of attribute currency_format.
30 31 32 |
# File 'lib/ynab/models/plan_summary.rb', line 30 def currency_format @currency_format end |
#date_format ⇒ Object
Returns the value of attribute date_format.
28 29 30 |
# File 'lib/ynab/models/plan_summary.rb', line 28 def date_format @date_format end |
#first_month ⇒ Object
The earliest plan month
23 24 25 |
# File 'lib/ynab/models/plan_summary.rb', line 23 def first_month @first_month end |
#id ⇒ Object
Returns the value of attribute id.
15 16 17 |
# File 'lib/ynab/models/plan_summary.rb', line 15 def id @id end |
#last_modified_on ⇒ Object
The last time any changes were made to the plan from either a web or mobile client
20 21 22 |
# File 'lib/ynab/models/plan_summary.rb', line 20 def last_modified_on @last_modified_on end |
#last_month ⇒ Object
The latest plan month
26 27 28 |
# File 'lib/ynab/models/plan_summary.rb', line 26 def last_month @last_month end |
#name ⇒ Object
Returns the value of attribute name.
17 18 19 |
# File 'lib/ynab/models/plan_summary.rb', line 17 def name @name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/ynab/models/plan_summary.rb', line 50 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/ynab/models/plan_summary.rb', line 36 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'last_modified_on' => :'last_modified_on', :'first_month' => :'first_month', :'last_month' => :'last_month', :'date_format' => :'date_format', :'currency_format' => :'currency_format', :'accounts' => :'accounts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/ynab/models/plan_summary.rb', line 169 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/ynab/models/plan_summary.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/ynab/models/plan_summary.rb', line 55 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'last_modified_on' => :'Time', :'first_month' => :'Date', :'last_month' => :'Date', :'date_format' => :'DateFormat', :'currency_format' => :'CurrencyFormat', :'accounts' => :'Array<Account>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/ynab/models/plan_summary.rb', line 141 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && last_modified_on == o.last_modified_on && first_month == o.first_month && last_month == o.last_month && date_format == o.date_format && currency_format == o.currency_format && accounts == o.accounts end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/ynab/models/plan_summary.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/ynab/models/plan_summary.rb', line 162 def hash [id, name, last_modified_on, first_month, last_month, date_format, currency_format, accounts].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 |
# File 'lib/ynab/models/plan_summary.rb', line 126 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/ynab/models/plan_summary.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 137 |
# File 'lib/ynab/models/plan_summary.rb', line 133 def valid? return false if @id.nil? return false if @name.nil? true end |