Class: YNAB::PlanSummaryResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::PlanSummaryResponseData
- Defined in:
- lib/ynab/models/plan_summary_response_data.rb
Instance Attribute Summary collapse
-
#budgets ⇒ Object
Returns the value of attribute budgets.
-
#default_budget ⇒ Object
Returns the value of attribute default_budget.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PlanSummaryResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PlanSummaryResponseData
Initializes the object
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 48 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::PlanSummaryResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::PlanSummaryResponseData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'budgets') if (value = attributes[:'budgets']).is_a?(Array) self.budgets = value end end if attributes.key?(:'default_budget') self.default_budget = attributes[:'default_budget'] end end |
Instance Attribute Details
#budgets ⇒ Object
Returns the value of attribute budgets.
15 16 17 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 15 def budgets @budgets end |
#default_budget ⇒ Object
Returns the value of attribute default_budget.
17 18 19 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 17 def default_budget @default_budget end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
28 29 30 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 28 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 20 def self.attribute_map { :'budgets' => :'budgets', :'default_budget' => :'default_budget' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 110 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
41 42 43 44 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 41 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 33 def self.openapi_types { :'budgets' => :'Array<PlanSummary>', :'default_budget' => :'PlanSummary' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
88 89 90 91 92 93 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 88 def ==(o) return true if self.equal?(o) self.class == o.class && budgets == o.budgets && default_budget == o.default_budget end |
#eql?(o) ⇒ Boolean
97 98 99 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 97 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
103 104 105 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 103 def hash [budgets, default_budget].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
74 75 76 77 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 74 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 132 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
81 82 83 84 |
# File 'lib/ynab/models/plan_summary_response_data.rb', line 81 def valid? return false if @budgets.nil? true end |