Class: YNAB::SaveCategory
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::SaveCategory
- Defined in:
- lib/ynab/models/save_category.rb
Instance Attribute Summary collapse
-
#category_group_id ⇒ Object
Returns the value of attribute category_group_id.
-
#goal_needs_whole_amount ⇒ Object
Whether the goal requires the full target amount each period.
-
#goal_target ⇒ Object
The goal target amount in milliunits format.
-
#goal_target_date ⇒ Object
The goal target date in ISO format (e.g. 2016-12-01).
-
#name ⇒ Object
Returns the value of attribute name.
-
#note ⇒ Object
Returns the value of attribute note.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SaveCategory
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SaveCategory
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/ynab/models/save_category.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::SaveCategory` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::SaveCategory`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'note') self.note = attributes[:'note'] end if attributes.key?(:'category_group_id') self.category_group_id = attributes[:'category_group_id'] end if attributes.key?(:'goal_target') self.goal_target = attributes[:'goal_target'] end if attributes.key?(:'goal_target_date') self.goal_target_date = attributes[:'goal_target_date'] end if attributes.key?(:'goal_needs_whole_amount') self.goal_needs_whole_amount = attributes[:'goal_needs_whole_amount'] end end |
Instance Attribute Details
#category_group_id ⇒ Object
Returns the value of attribute category_group_id.
19 20 21 |
# File 'lib/ynab/models/save_category.rb', line 19 def category_group_id @category_group_id end |
#goal_needs_whole_amount ⇒ Object
Whether the goal requires the full target amount each period. Only supported for ‘NEED’ goals. When true, the goal is configured as ‘Set aside another…’. When false, the goal is configured as ‘Refill up to…’.
28 29 30 |
# File 'lib/ynab/models/save_category.rb', line 28 def goal_needs_whole_amount @goal_needs_whole_amount end |
#goal_target ⇒ Object
The goal target amount in milliunits format. If value is specified and goal has not already been configured for category, a monthly goal will be created for the category with this target amount. If goal_type is not specified, it will default to ‘NEED’ or ‘MF’ for Credit Card Payment categories.
22 23 24 |
# File 'lib/ynab/models/save_category.rb', line 22 def goal_target @goal_target end |
#goal_target_date ⇒ Object
The goal target date in ISO format (e.g. 2016-12-01).
25 26 27 |
# File 'lib/ynab/models/save_category.rb', line 25 def goal_target_date @goal_target_date end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/ynab/models/save_category.rb', line 15 def name @name end |
#note ⇒ Object
Returns the value of attribute note.
17 18 19 |
# File 'lib/ynab/models/save_category.rb', line 17 def note @note end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/ynab/models/save_category.rb', line 43 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/ynab/models/save_category.rb', line 31 def self.attribute_map { :'name' => :'name', :'note' => :'note', :'category_group_id' => :'category_group_id', :'goal_target' => :'goal_target', :'goal_target_date' => :'goal_target_date', :'goal_needs_whole_amount' => :'goal_needs_whole_amount' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/ynab/models/save_category.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 64 65 66 67 68 |
# File 'lib/ynab/models/save_category.rb', line 60 def self.openapi_nullable Set.new([ :'name', :'note', :'goal_target', :'goal_target_date', :'goal_needs_whole_amount' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/ynab/models/save_category.rb', line 48 def self.openapi_types { :'name' => :'String', :'note' => :'String', :'category_group_id' => :'String', :'goal_target' => :'Integer', :'goal_target_date' => :'Date', :'goal_needs_whole_amount' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 134 |
# File 'lib/ynab/models/save_category.rb', line 125 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && note == o.note && category_group_id == o.category_group_id && goal_target == o.goal_target && goal_target_date == o.goal_target_date && goal_needs_whole_amount == o.goal_needs_whole_amount end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/ynab/models/save_category.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/ynab/models/save_category.rb', line 144 def hash [name, note, category_group_id, goal_target, goal_target_date, goal_needs_whole_amount].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 |
# File 'lib/ynab/models/save_category.rb', line 112 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/ynab/models/save_category.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
119 120 121 |
# File 'lib/ynab/models/save_category.rb', line 119 def valid? true end |