Class: YNAB::SaveCategory
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::SaveCategory
- Defined in:
- lib/ynab/models/save_category.rb
Instance Attribute Summary collapse
-
#category_group_id ⇒ Object
Returns the value of attribute category_group_id.
-
#goal_target ⇒ Object
The goal target amount in milliunits format.
-
#goal_target_date ⇒ Object
The goal target date in ISO format (e.g. 2016-12-01).
-
#name ⇒ Object
Returns the value of attribute name.
-
#note ⇒ Object
Returns the value of attribute note.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SaveCategory
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SaveCategory
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/ynab/models/save_category.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::SaveCategory` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::SaveCategory`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'note') self.note = attributes[:'note'] end if attributes.key?(:'category_group_id') self.category_group_id = attributes[:'category_group_id'] end if attributes.key?(:'goal_target') self.goal_target = attributes[:'goal_target'] end if attributes.key?(:'goal_target_date') self.goal_target_date = attributes[:'goal_target_date'] end end |
Instance Attribute Details
#category_group_id ⇒ Object
Returns the value of attribute category_group_id.
19 20 21 |
# File 'lib/ynab/models/save_category.rb', line 19 def category_group_id @category_group_id end |
#goal_target ⇒ Object
The goal target amount in milliunits format. If value is specified and goal has not already been configured for category, a monthly ‘Needed for Spending’ goal will be created for the category with this target amount.
22 23 24 |
# File 'lib/ynab/models/save_category.rb', line 22 def goal_target @goal_target end |
#goal_target_date ⇒ Object
The goal target date in ISO format (e.g. 2016-12-01).
25 26 27 |
# File 'lib/ynab/models/save_category.rb', line 25 def goal_target_date @goal_target_date end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/ynab/models/save_category.rb', line 15 def name @name end |
#note ⇒ Object
Returns the value of attribute note.
17 18 19 |
# File 'lib/ynab/models/save_category.rb', line 17 def note @note end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/ynab/models/save_category.rb', line 39 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 |
# File 'lib/ynab/models/save_category.rb', line 28 def self.attribute_map { :'name' => :'name', :'note' => :'note', :'category_group_id' => :'category_group_id', :'goal_target' => :'goal_target', :'goal_target_date' => :'goal_target_date' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/ynab/models/save_category.rb', line 140 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 59 60 61 62 |
# File 'lib/ynab/models/save_category.rb', line 55 def self.openapi_nullable Set.new([ :'name', :'note', :'goal_target', :'goal_target_date' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 |
# File 'lib/ynab/models/save_category.rb', line 44 def self.openapi_types { :'name' => :'String', :'note' => :'String', :'category_group_id' => :'String', :'goal_target' => :'Integer', :'goal_target_date' => :'Date' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
115 116 117 118 119 120 121 122 123 |
# File 'lib/ynab/models/save_category.rb', line 115 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && note == o.note && category_group_id == o.category_group_id && goal_target == o.goal_target && goal_target_date == o.goal_target_date end |
#eql?(o) ⇒ Boolean
127 128 129 |
# File 'lib/ynab/models/save_category.rb', line 127 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
133 134 135 |
# File 'lib/ynab/models/save_category.rb', line 133 def hash [name, note, category_group_id, goal_target, goal_target_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
102 103 104 105 |
# File 'lib/ynab/models/save_category.rb', line 102 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/ynab/models/save_category.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
109 110 111 |
# File 'lib/ynab/models/save_category.rb', line 109 def valid? true end |