Class: YNAB::ScheduledTransactionSummary
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::ScheduledTransactionSummary
- Defined in:
- lib/ynab/models/scheduled_transaction_summary.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#amount ⇒ Object
The scheduled transaction amount in milliunits format.
-
#amount_currency ⇒ Object
The scheduled transaction amount as a decimal currency amount.
-
#amount_formatted ⇒ Object
The scheduled transaction amount formatted in the plan’s currency format.
-
#category_id ⇒ Object
Returns the value of attribute category_id.
-
#date_first ⇒ Object
The first date for which the Scheduled Transaction was scheduled.
-
#date_next ⇒ Object
The next date for which the Scheduled Transaction is scheduled.
-
#deleted ⇒ Object
Whether or not the scheduled transaction has been deleted.
-
#flag_color ⇒ Object
Returns the value of attribute flag_color.
-
#flag_name ⇒ Object
The customized name of a transaction flag.
-
#frequency ⇒ Object
Returns the value of attribute frequency.
-
#id ⇒ Object
Returns the value of attribute id.
-
#memo ⇒ Object
Returns the value of attribute memo.
-
#payee_id ⇒ Object
Returns the value of attribute payee_id.
-
#transfer_account_id ⇒ Object
If a transfer, the account_id which the scheduled transaction transfers to.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScheduledTransactionSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScheduledTransactionSummary
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 138 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::ScheduledTransactionSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::ScheduledTransactionSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'date_first') self.date_first = attributes[:'date_first'] end if attributes.key?(:'date_next') self.date_next = attributes[:'date_next'] end if attributes.key?(:'frequency') self.frequency = attributes[:'frequency'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'memo') self.memo = attributes[:'memo'] end if attributes.key?(:'flag_color') self.flag_color = attributes[:'flag_color'] end if attributes.key?(:'flag_name') self.flag_name = attributes[:'flag_name'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'payee_id') self.payee_id = attributes[:'payee_id'] end if attributes.key?(:'category_id') self.category_id = attributes[:'category_id'] end if attributes.key?(:'transfer_account_id') self.transfer_account_id = attributes[:'transfer_account_id'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'amount_formatted') self.amount_formatted = attributes[:'amount_formatted'] end if attributes.key?(:'amount_currency') self.amount_currency = attributes[:'amount_currency'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
35 36 37 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 35 def account_id @account_id end |
#amount ⇒ Object
The scheduled transaction amount in milliunits format
26 27 28 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 26 def amount @amount end |
#amount_currency ⇒ Object
The scheduled transaction amount as a decimal currency amount
51 52 53 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 51 def amount_currency @amount_currency end |
#amount_formatted ⇒ Object
The scheduled transaction amount formatted in the plan’s currency format
48 49 50 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 48 def amount_formatted @amount_formatted end |
#category_id ⇒ Object
Returns the value of attribute category_id.
39 40 41 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 39 def category_id @category_id end |
#date_first ⇒ Object
The first date for which the Scheduled Transaction was scheduled.
18 19 20 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 18 def date_first @date_first end |
#date_next ⇒ Object
The next date for which the Scheduled Transaction is scheduled.
21 22 23 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 21 def date_next @date_next end |
#deleted ⇒ Object
Whether or not the scheduled transaction has been deleted. Deleted scheduled transactions will only be included in delta requests.
45 46 47 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 45 def deleted @deleted end |
#flag_color ⇒ Object
Returns the value of attribute flag_color.
30 31 32 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 30 def flag_color @flag_color end |
#flag_name ⇒ Object
The customized name of a transaction flag
33 34 35 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 33 def flag_name @flag_name end |
#frequency ⇒ Object
Returns the value of attribute frequency.
23 24 25 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 23 def frequency @frequency end |
#id ⇒ Object
Returns the value of attribute id.
15 16 17 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 15 def id @id end |
#memo ⇒ Object
Returns the value of attribute memo.
28 29 30 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 28 def memo @memo end |
#payee_id ⇒ Object
Returns the value of attribute payee_id.
37 38 39 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 37 def payee_id @payee_id end |
#transfer_account_id ⇒ Object
If a transfer, the account_id which the scheduled transaction transfers to
42 43 44 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 42 def transfer_account_id @transfer_account_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 97 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 76 def self.attribute_map { :'id' => :'id', :'date_first' => :'date_first', :'date_next' => :'date_next', :'frequency' => :'frequency', :'amount' => :'amount', :'memo' => :'memo', :'flag_color' => :'flag_color', :'flag_name' => :'flag_name', :'account_id' => :'account_id', :'payee_id' => :'payee_id', :'category_id' => :'category_id', :'transfer_account_id' => :'transfer_account_id', :'deleted' => :'deleted', :'amount_formatted' => :'amount_formatted', :'amount_currency' => :'amount_currency' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 277 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
130 131 132 133 134 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 130 def self.openapi_all_of [ :'ScheduledTransactionSummaryBase' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 127 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 123 def self.openapi_nullable Set.new([ :'flag_color', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 102 def self.openapi_types { :'id' => :'String', :'date_first' => :'Date', :'date_next' => :'Date', :'frequency' => :'String', :'amount' => :'Integer', :'memo' => :'String', :'flag_color' => :'TransactionFlagColor', :'flag_name' => :'String', :'account_id' => :'String', :'payee_id' => :'String', :'category_id' => :'String', :'transfer_account_id' => :'String', :'deleted' => :'Boolean', :'amount_formatted' => :'String', :'amount_currency' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && date_first == o.date_first && date_next == o.date_next && frequency == o.frequency && amount == o.amount && memo == o.memo && flag_color == o.flag_color && flag_name == o.flag_name && account_id == o.account_id && payee_id == o.payee_id && category_id == o.category_id && transfer_account_id == o.transfer_account_id && deleted == o.deleted && amount_formatted == o.amount_formatted && amount_currency == o.amount_currency end |
#eql?(o) ⇒ Boolean
264 265 266 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 264 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 270 def hash [id, date_first, date_next, frequency, amount, memo, flag_color, flag_name, account_id, payee_id, category_id, transfer_account_id, deleted, amount_formatted, amount_currency].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
214 215 216 217 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 214 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/ynab/models/scheduled_transaction_summary.rb', line 221 def valid? return false if @id.nil? return false if @date_first.nil? return false if @date_next.nil? return false if @frequency.nil? frequency_validator = EnumAttributeValidator.new('String', ["never", "daily", "weekly", "everyOtherWeek", "twiceAMonth", "every4Weeks", "monthly", "everyOtherMonth", "every3Months", "every4Months", "twiceAYear", "yearly", "everyOtherYear"]) return false unless frequency_validator.valid?(@frequency) return false if @amount.nil? return false if @account_id.nil? return false if @deleted.nil? true end |