Class: YNAB::SubTransaction
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- YNAB::SubTransaction
- Defined in:
- lib/ynab/models/sub_transaction.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The subtransaction amount in milliunits format.
-
#category_id ⇒ Object
Returns the value of attribute category_id.
-
#category_name ⇒ Object
Returns the value of attribute category_name.
-
#deleted ⇒ Object
Whether or not the subtransaction has been deleted.
-
#id ⇒ Object
Returns the value of attribute id.
-
#memo ⇒ Object
Returns the value of attribute memo.
-
#payee_id ⇒ Object
Returns the value of attribute payee_id.
-
#payee_name ⇒ Object
Returns the value of attribute payee_name.
-
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
-
#transfer_account_id ⇒ Object
If a transfer, the account_id which the subtransaction transfers to.
-
#transfer_transaction_id ⇒ Object
If a transfer, the id of transaction on the other side of the transfer.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubTransaction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SubTransaction
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/ynab/models/sub_transaction.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `YNAB::SubTransaction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `YNAB::SubTransaction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'transaction_id') self.transaction_id = attributes[:'transaction_id'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'memo') self.memo = attributes[:'memo'] end if attributes.key?(:'payee_id') self.payee_id = attributes[:'payee_id'] end if attributes.key?(:'payee_name') self.payee_name = attributes[:'payee_name'] end if attributes.key?(:'category_id') self.category_id = attributes[:'category_id'] end if attributes.key?(:'category_name') self.category_name = attributes[:'category_name'] end if attributes.key?(:'transfer_account_id') self.transfer_account_id = attributes[:'transfer_account_id'] end if attributes.key?(:'transfer_transaction_id') self.transfer_transaction_id = attributes[:'transfer_transaction_id'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end end |
Instance Attribute Details
#amount ⇒ Object
The subtransaction amount in milliunits format
20 21 22 |
# File 'lib/ynab/models/sub_transaction.rb', line 20 def amount @amount end |
#category_id ⇒ Object
Returns the value of attribute category_id.
28 29 30 |
# File 'lib/ynab/models/sub_transaction.rb', line 28 def category_id @category_id end |
#category_name ⇒ Object
Returns the value of attribute category_name.
30 31 32 |
# File 'lib/ynab/models/sub_transaction.rb', line 30 def category_name @category_name end |
#deleted ⇒ Object
Whether or not the subtransaction has been deleted. Deleted subtransactions will only be included in delta requests.
39 40 41 |
# File 'lib/ynab/models/sub_transaction.rb', line 39 def deleted @deleted end |
#id ⇒ Object
Returns the value of attribute id.
15 16 17 |
# File 'lib/ynab/models/sub_transaction.rb', line 15 def id @id end |
#memo ⇒ Object
Returns the value of attribute memo.
22 23 24 |
# File 'lib/ynab/models/sub_transaction.rb', line 22 def memo @memo end |
#payee_id ⇒ Object
Returns the value of attribute payee_id.
24 25 26 |
# File 'lib/ynab/models/sub_transaction.rb', line 24 def payee_id @payee_id end |
#payee_name ⇒ Object
Returns the value of attribute payee_name.
26 27 28 |
# File 'lib/ynab/models/sub_transaction.rb', line 26 def payee_name @payee_name end |
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
17 18 19 |
# File 'lib/ynab/models/sub_transaction.rb', line 17 def transaction_id @transaction_id end |
#transfer_account_id ⇒ Object
If a transfer, the account_id which the subtransaction transfers to
33 34 35 |
# File 'lib/ynab/models/sub_transaction.rb', line 33 def transfer_account_id @transfer_account_id end |
#transfer_transaction_id ⇒ Object
If a transfer, the id of transaction on the other side of the transfer
36 37 38 |
# File 'lib/ynab/models/sub_transaction.rb', line 36 def transfer_transaction_id @transfer_transaction_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/ynab/models/sub_transaction.rb', line 59 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/ynab/models/sub_transaction.rb', line 42 def self.attribute_map { :'id' => :'id', :'transaction_id' => :'transaction_id', :'amount' => :'amount', :'memo' => :'memo', :'payee_id' => :'payee_id', :'payee_name' => :'payee_name', :'category_id' => :'category_id', :'category_name' => :'category_name', :'transfer_account_id' => :'transfer_account_id', :'transfer_transaction_id' => :'transfer_transaction_id', :'deleted' => :'deleted' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/ynab/models/sub_transaction.rb', line 203 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/ynab/models/sub_transaction.rb', line 81 def self.openapi_nullable Set.new([ :'memo', :'payee_id', :'payee_name', :'category_id', :'category_name', :'transfer_account_id', :'transfer_transaction_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/ynab/models/sub_transaction.rb', line 64 def self.openapi_types { :'id' => :'String', :'transaction_id' => :'String', :'amount' => :'Integer', :'memo' => :'String', :'payee_id' => :'String', :'payee_name' => :'String', :'category_id' => :'String', :'category_name' => :'String', :'transfer_account_id' => :'String', :'transfer_transaction_id' => :'String', :'deleted' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/ynab/models/sub_transaction.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && transaction_id == o.transaction_id && amount == o.amount && memo == o.memo && payee_id == o.payee_id && payee_name == o.payee_name && category_id == o.category_id && category_name == o.category_name && transfer_account_id == o.transfer_account_id && transfer_transaction_id == o.transfer_transaction_id && deleted == o.deleted end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/ynab/models/sub_transaction.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/ynab/models/sub_transaction.rb', line 196 def hash [id, transaction_id, amount, memo, payee_id, payee_name, category_id, category_name, transfer_account_id, transfer_transaction_id, deleted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 |
# File 'lib/ynab/models/sub_transaction.rb', line 155 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/ynab/models/sub_transaction.rb', line 225 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 166 167 168 |
# File 'lib/ynab/models/sub_transaction.rb', line 162 def valid? return false if @id.nil? return false if @transaction_id.nil? return false if @amount.nil? return false if @deleted.nil? true end |